clear all 
set maxvar 100000
clear matrix
set matsize 11000
drop _all
set more off

cd "C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Analysis file for land and labour"
capture log close 
log using land_labour_analysis2.log, replace 

global IHPS_analysis Z:\Documents\Writing Papers\IHPS Malawi\MWI_2010-2013-2016_IHPS_v02_M_Stata
global temp_file_2016 C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Temporary data for land and labour\2016 Temp file
global temp_file_2013 C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Temporary data for land and labour\2013 Temp file
global temp_file_2010 C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Temporary data for land and labour\2010 Temp file
global appended_data C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Appended data for land and labour

*******************************

************ Working with balanced data ***************************************
use "$appended_data\land_labour_appended_IMRdatav2_with changes.dta", clear

xtset y3_hhid 
tabstat y3_hhid, stats(n) by (year)

/////////////////////////////////////////////////////////////////////////////
*********** Resource endowmwent variables *******************************

***** Assessing non-farming households
gen no_agr_13 = non_farmingHH_dummy if year==2013
egen no_agr_2013 = max (no_agr_13), by (y3_hhid)
gen no_agr_16 = non_farmingHH_dummy if year==2016
egen no_agr_2016 = max (no_agr_16), by (y3_hhid)
egen non_agrHH = rowtotal (no_agr_2013 no_agr_2016)

gen partly_farm_dummy =1 if non_agrHH==1
replace partly_farm_dummy=0 if partly_farm_dummy==.

gen non_farm_dummy =1 if non_agrHH==2
replace non_farm_dummy=0 if non_farm_dummy==.

tab non_agrHH
tab partly_farm_dummy
tab non_farm_dummy

******** Changes in area of owned land **************
gen ownland13 = owned_land_ha if year ==2013
egen ownland2013 = max (ownland13), by (y3_hhid)
gen ownland16 = owned_land_ha if year ==2016
egen ownland2016 = max (ownland16), by (y3_hhid)
gen diff_land_16_13 = ownland2016 - ownland2013

scatter diff_land_16_13 y3_hhid
kdensity diff_land_16_13

gen hh_labour13 = all_hh_labour if year==2013
egen hh_labour_2013 = max (hh_labour13), by(y3_hhid)
gen hh_labour16 = all_hh_labour if year==2016
egen hh_labour_2016 = max (hh_labour16), by(y3_hhid)
gen diff_labour_16_13 = hh_labour_2016 - hh_labour_2013

scatter diff_labour_16_13 y3_hhid
kdensity diff_labour_16_13

sum diff_land_16_13 diff_labour_16_13
sum diff_land_16_13 diff_labour_16_13 if rent_dummy==0
sum diff_land_16_13 diff_labour_16_13 if rent_dummy==1
sum diff_land_16_13 diff_labour_16_13 if no_ownland_dummy==0
sum diff_land_16_13 diff_labour_16_13 if no_ownland_dummy==1
sum diff_land_16_13 diff_labour_16_13 if hireout_labour_ganyu_dummy==0
sum diff_land_16_13 diff_labour_16_13 if hireout_labour_ganyu_dummy==1


*order owned_land_ha farmland_ha year ownland2013 ownland2016 diff_land_16_13
***********************************************************************************
gen farm_hh_type = 1 if rent_dummy==0 & hireout_labour_ganyu_dummy==0 & non_farmingHH_dummy!=1
replace farm_hh_type = 2 if rent_dummy==1 & hireout_labour_ganyu_dummy!=1 & non_farmingHH_dummy!=1
replace farm_hh_type = 3 if hireout_labour_ganyu_dummy==1 & rent_dummy!=1 & non_farmingHH_dummy!=1
replace farm_hh_type = 4 if hireout_labour_ganyu_dummy==1 & rent_dummy==1 & non_farmingHH_dummy!=1
replace farm_hh_type = 5 if hireout_labour_ganyu_dummy==1 & rent_dummy!=1 & non_farmingHH_dummy==1
replace farm_hh_type = 6 if hireout_labour_ganyu_dummy!=1 & rent_dummy!=1 & non_farmingHH_dummy==1 & non_agrHH==1
replace farm_hh_type = 7 if hireout_labour_ganyu_dummy!=1 & rent_dummy!=1 & non_farmingHH_dummy==1 & non_agrHH==2


lab define farmer 1"Farming_Non_participant" 2"Rent_in_land" 3"Farming_Hire_out_lab" 4"Both_rentin_hireout" 5 "No_farming_hire_out" 6 "part_farming_No_hire_out" 7 "No_farming_No_hire_out"
lab values farm_hh_type farmer
tab farm_hh_type


************ Generating the dummy for each category******************
gen farming_non_partic=1 if farm_hh_type==1 
replace farming_non_partic=0 if farming_non_partic==.

gen rent_in_land=1 if farm_hh_type==2 
replace rent_in_land=0 if rent_in_land==.

gen farming_hireout_lab=1 if farm_hh_type==3 
replace farming_hireout_lab=0 if farming_hireout_lab==.

gen both_rentin_hireout=1 if farm_hh_type==4 
replace both_rentin_hireout=0 if both_rentin_hireout==.

gen No_farming_hireout=1 if farm_hh_type == 5
replace No_farming_hireout=0 if No_farming_hireout==.

gen part_farming_No_hire_out=1 if farm_hh_type==6
replace part_farming_No_hire_out=0 if part_farming_No_hire_out==.

gen No_farming_No_hireout=1 if farm_hh_type==7
replace No_farming_No_hireout=0 if No_farming_No_hireout==.

rename hireout_labour_ganyu_dummy ganyu_dummy
*******************************************************************************

tab farming_non_partic
tab rent_in_land
tab farming_hireout_lab
tab both_rentin_hireout
tab No_farming_hireout
tab part_farming_No_hire_out
tab No_farming_No_hireout

******** Generating household wealth quantiles ********************
tabstat owned_land_ha, stats (p25 p50 p75 n)
gen Q2_owned_land_ha = 1 if owned_land_ha>0 & owned_land_ha<=0.3
replace Q2_owned_land_ha=0 if Q2_owned_land_ha==.
gen Q3_owned_land_ha = 1 if owned_land_ha>0.3 & owned_land_ha<=0.7
replace Q3_owned_land_ha=0 if Q3_owned_land_ha==.
gen Q4_owned_land_ha = 1 if owned_land_ha>0.7
replace Q4_owned_land_ha=0 if Q4_owned_land_ha==.

****************************************************
//Capital to labour ratio
gen capital_ratio = capital_asset_score/all_hh_labour
tabstat capital_ratio, stats (p25 p50 p75 n)

gen cap_ratio_Q1 = 1 if capital_ratio<=-0.2165
replace cap_ratio_Q1 = 0 if cap_ratio_Q1==.

gen cap_ratio_Q2 = 1 if capital_ratio>-0.2165 & capital_ratio<=-0.1131
replace cap_ratio_Q2 = 0 if cap_ratio_Q2==.

gen cap_ratio_Q3 = 1 if capital_ratio>-0.1131 & capital_ratio<=0.0323
replace cap_ratio_Q3 = 0 if cap_ratio_Q3==.

gen cap_ratio_Q4 = 1 if capital_ratio>0.0323
replace cap_ratio_Q4 = 0 if cap_ratio_Q4==.

tabstat cap_ratio_Q1 cap_ratio_Q2 cap_ratio_Q3 cap_ratio_Q4, stats (mean n)

**********************************************************************
////////////////////////////////////////////////////////////////////

********** Descriptive statistics *********************************************
****** Lorens curves for distribution of land and labour resources *********
*lorenz estimate own_farmland_labour_ratio, over(farm_hh_type) 
*lorenz graph, aspectratio(1) overlay 

lorenz own_farmland_labour_ratio if non_farmingHH_dummy!=1, over(farm_hh_type) graph (overlay aspectratio(1) xlabels(, nogrid labsize(small)) ylabels(, nogrid labsize(small)) title ("A: Owned Land to Labour ratio", size(medsmall) color(black)) ytitle("Cummulative outcome proportion",size(small)) xtitle("Population percentage",size(small)) labels("Farming non-participant; 26%" "Rent-in the land; 5%" "Farming-hireout labour; 38%" "Both rent-in and hireout; 4%") legend(position(3) cols(1) stack rowgap(4) size(small)) noci diag(lp (dot) lwidth(*2)) o1(lp(solid) lwidth(*1.5)) o2(lp(shortdash) lwidth(*2.0)) o3(lp("__..")) o4(lp("-...") lwidth(*2) lcolor(orange_red)) note("Graph excludes HHs with no operational farmland." "i.No-farming - hireout labour: 10%" "ii.No-farming - No hireout labour: 17%", size(small) pos(7)))
graph save lorenz_ratio.gph, asis replace 


lorenz total_farmland_labour_ratio if non_farmingHH_dummy!=1, over(farm_hh_type) graph (overlay aspectratio(1) xlabels(, nogrid labsize(small)) ylabels(, nogrid labsize(small)) title ("B: Operational Farmland to Labour ratio", size(medsmall) color(black)) ytitle("Cummulative outcome proportion",size(small)) xtitle("Population percentage",size(small)) labels("Farming non-participant; 26%" "Rent-in the land; 5%" "Farming-hireout labour; 38%" "Both rent-in and hire out; 4%") legend(position(3) cols(1) stack rowgap(4) size(small)) noci diag(lp (dot) lwidth(*2)) o1(lp(solid) lwidth(*1.5)) o2(lp(shortdash) lwidth(*2.0)) o3(lp("__...")) o4(lp(shortdash_dot) lwidth(*2) lcolor(orange_red)) note("Graph excludes HHs with no operational farmland." "i.No-farming - hireout labour: 10%" "ii.No-farming - No hireout labour: 17%", size(small) pos(7)))
graph save lorenz_ratio22.gph, asis replace 


lorenz own_farmland_labour_ratio total_farmland_labour_ratio, graph (overlay aspectratio(1) xlabels(, nogrid labsize(small)) ylabels(, nogrid labsize(small)) title ("Household Owned Land to Labour endowmwent ratio", size(medsmall)) ytitle("Cummulative outcome proportion",size(small)) xtitle("Population percentage",size(small)) labels("Owned land" "operational land") legend(position(3) cols(1) stack rowgap(4) size(small)) noci diag(lp (dot) lwidth(*2)) o1(lp(solid) lwidth(*1.5)) o2(lp(shortdash) lwidth(*3.0)))

lorenz owned_land_ha total_culti_land_ha, graph (overlay aspectratio(1) xlabels(, nogrid labsize(small)) ylabels(, nogrid labsize(small)) title ("Household Owned Land to Labour endowmwent ratio", size(medsmall)) ytitle("Cummulative outcome proportion",size(small)) xtitle("Population percentage",size(small)) labels("Owned land" "operational land") legend(position(3) cols(1) stack rowgap(4) size(small)) noci diag(lp (dot) lwidth(*2)) o1(lp(solid) lwidth(*1.5)) o2(lp(shortdash) lwidth(*3.0)))


****************************************************
tab rent_dummy
tab ganyu_dummy
tab farming_non_partic
tab part_farming_No_hire_out
tab No_farming_No_hireout


rename no_ownland_dummy  landless 
/////////// Summary statistics //////////////////
tabstat rent_dummy ganyu_dummy farming_non_partic No_farming_No_hireout share_ganyu_adultEqui_lab, stats( mean sem min max n) by(year)

******** Land rented in 
tabstat total_rent_land_ha, stats(mean sem min max n) by (year)
tabstat total_rent_land_ha if rent_dummy==1, stats(mean sem min max n) by (year)

********** Endowment variables *************
// rent dummy == 1
tabstat owned_land_ha total_culti_land_ha no_pre_rentalland_dummy all_hh_labour own_farmland_labour_ratio total_farmland_labour_ratio capital_asset_score cap_ratio_Q1 cap_ratio_Q2 cap_ratio_Q3 cap_ratio_Q4 if rent_dummy==1, stats(mean sem min max n) by (year)

// ganyu_dummy == 1
tabstat  owned_land_ha total_culti_land_ha no_pre_rentalland_dummy all_hh_labour own_farmland_labour_ratio total_farmland_labour_ratio capital_asset_score cap_ratio_Q1 cap_ratio_Q2 cap_ratio_Q3 cap_ratio_Q4 if ganyu_dummy==1, stats(mean sem min max n) by (year)

//farming_non_partic == 1
tabstat  owned_land_ha total_culti_land_ha no_pre_rentalland_dummy all_hh_labour own_farmland_labour_ratio total_farmland_labour_ratio capital_asset_score cap_ratio_Q1 cap_ratio_Q2 cap_ratio_Q3 cap_ratio_Q4 if farming_non_partic==1, stats(mean sem min max n) by (year)

// part_farming_No_hire_out ==1
tabstat  owned_land_ha total_culti_land_ha no_pre_rentalland_dummy all_hh_labour own_farmland_labour_ratio total_farmland_labour_ratio capital_asset_score cap_ratio_Q1 cap_ratio_Q2 cap_ratio_Q3 cap_ratio_Q4 if part_farming_No_hire_out ==1, stats(mean sem min max n) by (year)

// No_farming_No_hireout ==1
tabstat  owned_land_ha total_culti_land_ha no_pre_rentalland_dummy all_hh_labour own_farmland_labour_ratio total_farmland_labour_ratio capital_asset_score cap_ratio_Q1 cap_ratio_Q2 cap_ratio_Q3 cap_ratio_Q4 if No_farming_No_hireout ==1, stats(mean sem min max n) by (year)

// Overall
*tabstat diff_land_16_13 diff_labour_16_13, stats(mean sem min max n) by (year)

*tabstat own_farmland_labour_ratio share_male_total_labour wealth_Q1 wealth_Q2 wealth_Q3 wealth_Q4 no_ownland_dummy owned_land_ha total_culti_land_ha , stats(mean sem min max n) by (year)

****************** Household control chacteristics 

// rent dummy == 1
tabstat   sex_hh age_hh edu_head hhsize_labour_ratio TLU_labour_ratio yr_one_lag_TLU_labour_ratio dist_popcenter if rent_dummy==1, stats(mean sem min max n) by (year)

// ganyu_dummy == 1
tabstat sex_hh age_hh edu_head hhsize_labour_ratio TLU_labour_ratio yr_one_lag_TLU_labour_ratio dist_popcenter if ganyu_dummy==1, stats(mean sem min max n) by (year)

//farming_non_partic == 1
tabstat sex_hh age_hh edu_head hhsize_labour_ratio TLU_labour_ratio yr_one_lag_TLU_labour_ratio dist_popcenter if farming_non_partic==1, stats(mean sem min max n) by (year)

//part_farming_No_hire_out ==1
tabstat sex_hh age_hh edu_head hhsize_labour_ratio TLU_labour_ratio yr_one_lag_TLU_labour_ratio dist_popcenter if part_farming_No_hire_out ==1, stats(mean sem min max n) by (year)

//No_farming_No_hireout ==1
tabstat sex_hh age_hh edu_head hhsize_labour_ratio TLU_labour_ratio yr_one_lag_TLU_labour_ratio dist_popcenter if No_farming_No_hireout ==1, stats(mean sem min max n) by (year)

// Overall
*tabstat sex_hh age_hh edu_head hhsize_labour_ratio TLU_labour_ratio yr_one_lag_TLU_labour_ratio dist_popcenter, stats(mean sem min max n) by (year)
****************
// Rainfall variable
tabstat lag1_pstive_early_mid lag1_Negatv_early_mid, stats(mean sem min max n) by (year)
**********************************************************************************

*********** ttest ********************
gen rent_hire = 1 if rent_dummy==1 // For ttest analysis 
replace rent_hire = 0 if ganyu_dummy==1 & rent_hire==. 
tab rent_hire 

ttest owned_land_ha,  by(rent_hire)
ttest total_culti_land_ha, by(rent_hire)
ttest no_pre_rentalland_dummy, by(rent_hire)
ttest all_hh_labour, by(rent_hire)
ttest own_farmland_labour_ratio, by(rent_hire)
ttest total_farmland_labour_ratio, by(rent_hire)
ttest capital_asset_score, by(rent_hire)
ttest cap_ratio_Q1, by(rent_hire)
ttest cap_ratio_Q2, by(rent_hire)
ttest cap_ratio_Q3, by(rent_hire)
ttest cap_ratio_Q4, by(rent_hire)

ttest sex_hh, by(rent_hire)
ttest age_hh, by(rent_hire)
ttest edu_head, by(rent_hire)
ttest hhsize_labour_ratio, by(rent_hire)
ttest TLU_labour_ratio, by(rent_hire)
ttest yr_one_lag_TLU_labour_ratio, by(rent_hire)
ttest dist_popcenter, by(rent_hire)
 
/////////////////////////////////////////////////////////////////////////////////
*********************************************************************************
*
****************************  ****************************
// globals for control variables
global xtlist_cmp1  own_farmland_labour_ratio cap_ratio_Q1 cap_ratio_Q2 cap_ratio_Q3 no_pre_rentalland_dummy     

*no_ownland_dummy  
*labour_land_ratio capital_asset_score 
// Include control variables
global xlist_land_control   lag1_pstive_early_mid lag1_Negatv_early_mid sex_hh age_hh edu_head hhsize_labour_ratio TLU_labour_ratio yr_one_lag_TLU_labour_ratio dist_popcenter ib(2).region 

global xlist_labour_control  lag1_pstive_early_mid lag1_Negatv_early_mid sex_hh age_hh edu_head hhsize_labour_ratio TLU_labour_ratio yr_one_lag_TLU_labour_ratio  dist_popcenter ib(2).region 

*dm_postve_dev_svyrEarly dm_abs_negtve_dev_svyrEarly

// Include mean and sd for control variables 
global xtlist_CRE_land_mean_sd    lag1_pstive_early_mid lag1_Negatv_early_mid  mean_sex_hh mean_age_hh mean_edu_head  mean_hhsize_labour_ratio mean_TLU_labour_ratio mean_yr_one_lag_TLU_labour_ratio mean_dist_popcenter dev_sex_hh dev_age_hh dev_edu_head   dev_hhsize_labour_ratio dev_TLU_labour_ratio dev_yr_one_lag_TLU_labour_ratio dev_dist_popcenter  ib(2).region

global xtlist_CRE_labour_mean_sd    lag1_pstive_early_mid lag1_Negatv_early_mid  mean_sex_hh mean_age_hh mean_edu_head  mean_hhsize_labour_ratio mean_TLU_labour_ratio mean_yr_one_lag_TLU_labour_ratio mean_dist_popcenter dev_sex_hh dev_age_hh dev_edu_head   dev_hhsize_labour_ratio dev_TLU_labour_ratio dev_yr_one_lag_TLU_labour_ratio dev_dist_popcenter  ib(2).region

*************************************************************************************

****************

cmp setup
*********************** Probit model ****************************************
// Parsimonious models

cmp (rent_dummy= $xtlist_cmp1 i.year) (ganyu_dummy= $xtlist_cmp1 i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_result1
eststo cmp_margins_rent1: estpost margins, dydx(*) predict(pr eq(rent_dummy)) nochainrule
 
cmp (rent_dummy= $xtlist_cmp1 i.year) (ganyu_dummy= $xtlist_cmp1 i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_result1
eststo cmp_margins_hire1: estpost margins, dydx(*) predict(pr eq(ganyu_dummy)) nochainrule

cmp (rent_dummy= $xtlist_cmp1 i.year) (ganyu_dummy= rent_dummy $xtlist_cmp1 i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_result2
eststo cmp_margins_rent2: estpost margins, dydx(*) predict(pr eq(rent_dummy)) nochainrule

cmp (rent_dummy= $xtlist_cmp1 i.year) (ganyu_dummy= rent_dummy $xtlist_cmp1 i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_result2
eststo cmp_margins_hire2: estpost margins, dydx(*) predict(pr eq(ganyu_dummy)) nochainrule

esttab cmp_margins_rent1 cmp_margins_hire1 cmp_margins_rent2 cmp_margins_hire2 using "cmp_parsi_control_results.csv", b(3) se(2) nonumber mtitle("cmp_margin_rent1" "cmp_margin_hire1" "cmp_margin_rent2" "cmp_margin_hire2") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 
*************************************************

// Model with controls 
*********************************************************
cmp (rent_dummy= $xtlist_cmp1 $xlist_land_control i.year) (ganyu_dummy= $xtlist_cmp1 $xlist_labour_control i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_result11
eststo cmp_margins_rent11: estpost margins, dydx(*) predict(pr eq(rent_dummy)) nochainrule
 
cmp (rent_dummy= $xtlist_cmp1 $xlist_land_control i.year) (ganyu_dummy= $xtlist_cmp1 $xlist_labour_control i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_result11
eststo cmp_margins_hire11: estpost margins, dydx(*) predict(pr eq(ganyu_dummy)) nochainrule

cmp (rent_dummy= $xtlist_cmp1 $xlist_land_control i.year) (ganyu_dummy= rent_dummy $xtlist_cmp1 $xlist_labour_control i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_result22
eststo cmp_margins_rent22: estpost margins, dydx(*) predict(pr eq(rent_dummy)) nochainrule

cmp (rent_dummy= $xtlist_cmp1 $xlist_land_control i.year) (ganyu_dummy= rent_dummy $xtlist_cmp1 $xlist_labour_control i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_result22
eststo cmp_margins_hire22: estpost margins, dydx(*) predict(pr eq(ganyu_dummy)) nochainrule

**************************************************************
esttab cmp_margins_rent11 cmp_margins_hire11 cmp_margins_rent22 cmp_margins_hire22 using "cmp_parsi_depent_control_results.csv", b(3) se(2) nonumber mtitle("cmp_margin_rent11" "cmp_margin_hire11" "cmp_margin_rent22" "cmp_margin_hire22") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 
*************************************************************************
*
*********************************************************************************
************************************************************************

// Model with mean and sd controls 
*********************************************************
cmp (rent_dummy= $xtlist_cmp1 $xtlist_CRE_land_mean_sd i.year) (ganyu_dummy= $xtlist_cmp1 $xtlist_CRE_labour_mean_sd i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store mean_result11
eststo mean_margins_rent11: estpost margins, dydx(*) predict(pr eq(rent_dummy)) nochainrule
 
cmp (rent_dummy= $xtlist_cmp1 $xtlist_CRE_land_mean_sd i.year) (ganyu_dummy= $xtlist_cmp1 $xtlist_CRE_labour_mean_sd i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store mean_result11
eststo mean_margins_hire11: estpost margins, dydx(*) predict(pr eq(ganyu_dummy)) nochainrule

cmp (rent_dummy= $xtlist_cmp1 $xtlist_CRE_land_mean_sd i.year) (ganyu_dummy= rent_dummy $xtlist_cmp1 $xtlist_CRE_labour_mean_sd i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store mean_result22
eststo mean_margins_rent22: estpost margins, dydx(*) predict(pr eq(rent_dummy)) nochainrule

cmp (rent_dummy= $xtlist_cmp1 $xtlist_CRE_land_mean_sd i.year) (ganyu_dummy= rent_dummy $xtlist_cmp1 $xtlist_CRE_labour_mean_sd i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store mean_result22
eststo mean_margins_hire22: estpost margins, dydx(*) predict(pr eq(ganyu_dummy)) nochainrule


**************************************************************
esttab mean_margins_rent11 mean_margins_hire11 mean_margins_rent22 mean_margins_hire22 using "mean_depent_control_results.csv", b(3) se(2) nonumber mtitle("cmp_mean_rent11" "cmp_mean_hire11" "cmp_mean_rent22" "cmp_mean_hire22") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 
*************************************************************************
*
*
*********** Estimated coefficients, all results ***************
********************************************************************************
// Main results : Margins
esttab cmp_margins_rent11 cmp_margins_hire11 cmp_margins_rent22 cmp_margins_hire22 mean_margins_rent11 mean_margins_hire11 mean_margins_rent22 mean_margins_hire22 using "cmp_parsi_depent_control_all.csv", b(3) se(2) nonumber mtitle("cmp_margin_rent11" "cmp_margin_hire11" "cmp_margin_rent22" "cmp_margin_hire22" "cmp_mean_rent11" "cmp_mean_hire11" "cmp_mean_rent22" "cmp_mean_hire22") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 

// Main results : Coefficients 
outreg2 [cmp_result11 cmp_result22 mean_result11 mean_result22 ] using cmp_document_coef, stats(coef se ) paren(se) bdec(3) sdec(2) alpha(0.001, 0.01, 0.05, 0.1) symbol(****, ***, **, *) word excel replace see
***********************************

********************************************************************************
// All model results, too many to present all in one table
*esttab cmp_margins_rent1 cmp_margins_hire1 cmp_margins_rent2 cmp_margins_hire2 cmp_margins_rent11 cmp_margins_hire11 cmp_margins_rent22 cmp_margins_hire22 mean_margins_rent11 mean_margins_hire11 mean_margins_rent22 mean_margins_hire22 using "CMP_CRE_control_all.csv", b(3) se(2) nonumber mtitle("cmp_margin_rent11" "cmp_margin_hire11" "cmp_margin_rent22" "cmp_margin_hire22") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 

*outreg2 [cmp_result1 cmp_result2 cmp_result11 cmp_result22 mean_result11 mean_result22 ] using cmp_all_coeff, stats(coef se ) paren(se) bdec(3) sdec(2) alpha(0.001, 0.01, 0.05, 0.1) symbol(****, ***, **, *) word excel replace see

***************************************************************************
*
*
*
*
*
*
*
*
*
*
*
******* Tobit  and fractional probit models for extent of participation ***************
********* These models do not account for recursive in extent participation ******  
// Parsimonious models
cmp setup

cmp (total_rent_land_ha= $xtlist_cmp1 i.year) (share_ganyu_adultEqui_lab= $xtlist_cmp1 i.year), ind("cond(total_rent_land_ha, $cmp_cont, $cmp_left)" $cmp_frac) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_ext_rent1
estpost margins, dydx(*) predict(pr eq(total_rent_land_ha)) nochainrule
eststo cmp_margins_ext_rent1

cmp (total_rent_land_ha= $xtlist_cmp1 i.year) (share_ganyu_adultEqui_lab= $xtlist_cmp1 i.year), ind("cond(total_rent_land_ha, $cmp_cont, $cmp_left)" $cmp_frac) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_ext_hire1
estpost margins, dydx(*) predict(pr eq(share_ganyu_adultEqui_lab)) nochainrule
eststo cmp_margins_ext_hire1

*******************************************
esttab cmp_margins_ext_rent1 cmp_margins_ext_hire1 using "cmp_parsi_ext.csv", b(3) se(2) nonumber mtitle("cmp_margin_rent1" "cmp_margin_hire1" "cmp_margin_rent2" "cmp_margin_hire2") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 
*************************************************
*
*
*
// Model with controls 
*********************************************************
cmp (total_rent_land_ha= $xtlist_cmp1 $xlist_land_control i.year) (share_ganyu_adultEqui_lab= $xtlist_cmp1 $xlist_labour_control i.year), ind("cond(total_rent_land_ha, $cmp_cont, $cmp_left)" $cmp_frac) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_ext_rent11
estpost margins, dydx(*) predict(pr eq(total_rent_land_ha)) nochainrule
eststo cmp_margins_ext_rent11

cmp (total_rent_land_ha= $xtlist_cmp1 $xlist_land_control i.year) (share_ganyu_adultEqui_lab= $xtlist_cmp1 $xlist_labour_control i.year), ind("cond(total_rent_land_ha, $cmp_cont, $cmp_left)" $cmp_frac) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store cmp_ext_hire11
estpost margins, dydx(*) predict(pr eq(share_ganyu_adultEqui_lab)) nochainrule
eststo cmp_margins_ext_hire11

**************************************************************
esttab cmp_margins_ext_rent11 cmp_margins_ext_hire11  using "cmp_parsi_coeffic_ext.csv", b(3) se(2) nonumber mtitle("cmp_margin_rent11" "cmp_margin_hire11" "cmp_margin_rent22" "cmp_margin_hire22") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 
*************************************************************************

// Model with mean and sd controls 
*********************************************************
cmp (total_rent_land_ha= $xtlist_cmp1 $xtlist_CRE_land_mean_sd i.year) (share_ganyu_adultEqui_lab= $xtlist_cmp1 $xtlist_CRE_labour_mean_sd i.year), ind("cond(total_rent_land_ha, $cmp_cont, $cmp_left)" $cmp_frac) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store mean_ext_rent11
estpost margins, dydx(*) predict(pr eq(total_rent_land_ha)) nochainrule
eststo mean_margins_ext_rent11

cmp (total_rent_land_ha= $xtlist_cmp1 $xtlist_CRE_land_mean_sd i.year) (share_ganyu_adultEqui_lab= $xtlist_cmp1 $xtlist_CRE_labour_mean_sd i.year), ind("cond(total_rent_land_ha, $cmp_cont, $cmp_left)" $cmp_frac) nodrop nolr tech(dfp) ghkd(200) qui cluster (y3_hhid)
estimate store mean_ext_hire11
estpost margins, dydx(*) predict(pr eq(share_ganyu_adultEqui_lab)) nochainrule
eststo mean_margins_ext_hire11

**************************************************************
esttab mean_margins_ext_rent11 mean_margins_ext_hire11 using "mean_coeffic_ext.csv", b(3) se(2) nonumber mtitle("cmp_margin_rent11" "cmp_margin_hire11" "cmp_margin_rent22" "cmp_margin_hire22") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 
*************************************************************************

********************************************************************************
*********************** Main results *******************
// Margins
esttab cmp_margins_ext_rent11 cmp_margins_ext_hire11 mean_margins_ext_rent11 mean_margins_ext_hire11 using "mean_allmagn_ext.csv", b(3) se(2) nonumber mtitle("cmp_margin_rent11" "cmp_margin_hire11" "cmp_margin_rent22" "cmp_margin_hire22") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 
// Coefficients
outreg2 [cmp_ext_rent11 mean_ext_rent11] using mean_exte_margins, stats(coef se ) paren(se) bdec(3) sdec(2) alpha(0.001, 0.01, 0.05, 0.1) symbol(****, ***, **, *) word excel replace see


***************** Results too long to present********************************
// All Margins
*esttab cmp_margins_ext_rent1 cmp_margins_ext_hire1 cmp_margins_ext_rent11 cmp_margins_ext_hire11 mean_margins_ext_rent11 mean_margins_ext_hire11 using "mean_allmagn_long.csv", b(3) se(2) nonumber mtitle("cmp_margin_rent11" "cmp_margin_hire11" "cmp_margin_rent22" "cmp_margin_hire22") star (* 0.1 ** 0.05 *** 0.01 **** 0.001) replace 
// All coefficients
*outreg2 [cmp_ext_rent1 cmp_ext_rent11 mean_ext_rent11] using mean_exte_allcoef, stats(coef se ) paren(se) bdec(3) sdec(2) alpha(0.001, 0.01, 0.05, 0.1) symbol(****, ***, **, *) word excel replace see

**********************************************************************************
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*****************************************************************************
************ My sources of CMP **********************************************
Logically possible models include:

cmp (cooking_fuel = x1 x2 x3 x4 lighting_fuel# i.year ) (lighting_fuel = x1 x2 x3 cooking_fuel i.year), ind($cmp_probit $cmp_probit ) cluster(hhid)

cmp (cooking_fuel = x1 x2 x3 x4 lighting_fuel i.year ) (lighting_fuel = x1 x2 x3 cooking_fuel# i.year), ind($cmp_probit $cmp_probit ) cluster(hhid)

cmp (cooking_fuel = x1 x2 x3 x4 lighting_fuel# i.year ) (lighting_fuel = x1 x2 x3 cooking_fuel# i.year), ind($cmp_probit $cmp_probit ) cluster(hhid)

cmp (labor = health X1 X3) (health = labor# X2 X3) ind($cmp_probit $cmp_oprobit)
cmp (labor = health# X1 X3) (health = labor X2 X3) ind($cmp_probit $cmp_oprobit)
cmp (labor = health# X1 X3) (health = labor# X2 X3) ind($cmp_probit $cmp_oprobit)

cmp (hireout_labour_ganyu_dummy= $xtlist_cmp1 $xlist_land_control rent_dummy#i.year) (rent_dummy= $xtlist_cmp1 $xlist_land_control hireout_labour_ganyu_dummy#i.year), ind($cmp_probit $cmp_probit) nodrop nolr tech(dfp) ghkd(200) qui vce(cluster y3_hhid)
**********************************************************

cmp (manure= $drought1 $drought2 $rainfall $endo $region $asset1 $price $hhxr1 $plot1 $year $means) (logmanure= $drought1 $drought2 $rainfall $endo $region $asset1 $price $hhxr1 $plot1 $year $means), ind(4 "cond(logmanure, $cmp_cont, $cmp_left)") nodrop nolr tech(dfp) ghkd(200) qui vce(cluster hhid)

****************************************************************************************************
*
*
*
*
*
log close
log translate land_labour_analysis2.log land_labour_analysis2.pdf, replace
