clear all 
set more off 
set maxvar 100000
cd "C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Analysis file for land and labour"
capture log close 
log using land_labour_decisions.log, replace 

global IHPS_analysis Z:\Documents\Writing Papers\IHPS Malawi\MWI_2010-2013-2016_IHPS_v02_M_Stata
global temp_file_2016 C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Temporary data for land and labour\2016 Temp file
global temp_file_2013 C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Temporary data for land and labour\2013 Temp file
global temp_file_2010 C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Temporary data for land and labour\2010 Temp file
global appended_data C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land and labour decisions with shocks analysis\Appended data for land and labour

************** Rainfall data *********************************
global rain_appended_file C:\Users\sarahti\OneDrive - Norwegian University of Life Sciences\Documents\Writing Papers\Land rental participation and rainfall variations analysis\Appended files on rainfall and land markets


*
*
// First step was to identify the year one households in year three since the 
// households were spliting into multiple households.
// I wanted to maintain the y3_hhid as unique ID for all the years 
use "$IHPS_analysis\hh_mod_a_filt_16.dta", clear
merge m:1 HHID using "$IHPS_analysis\hh_mod_a_filt_10.dta", force
drop _merge
destring y3_hhid, ignore ("-") replace
destring y2_hhid, ignore ("-") replace
destring ea_id, ignore ("-") replace
sort HHID y3_hhid
quietly by HHID : gen dup1 = cond(_N==1,0,_n)
keep if dup1<=1
count 
save "$temp_file_2010\2010_y3_hhid.dta", replace 

use "$IHPS_analysis\hh_mod_a_filt_16.dta", clear
merge m:1 y2_hhid using "$IHPS_analysis\hh_mod_a_filt_13.dta", force
drop _merge
destring y3_hhid, ignore ("-") replace
destring y2_hhid, ignore ("-") replace
destring ea_id, ignore ("-") replace
sort y2_hhid y3_hhid
quietly by y2_hhid : gen dup1 = cond(_N==1,0,_n)
keep if dup1<=1
count
save "$temp_file_2013\2013_y3_hhid.dta", replace 


********************************************************************************
*
*
*
*
************** Organising the data by year *************************************
*
*
*
************ Working with 2016 household data *****************************
use "$IHPS_analysis\hh_mod_a_filt_16.dta", clear // Household listing 
merge 1:1 y3_hhid using "$IHPS_analysis\hh_mod_x_16.dta", nogen
rename hh_x10 hh_x10_2015_16 
count
gen inter_date_v1 = date(interviewdate_v1, "YMD")
format %td inter_date_v1 
lab var inter_date_v1 "Interview Date Visit 1"
gen inter_date_v2 = date(interviewdate_v2, "YMD")
format %td inter_date_v2
lab var inter_date_v2 "Interview Date Visit 2"

merge 1:m y3_hhid using "$IHPS_analysis\hh_mod_b_16.dta", nogen // Household roster
gen year=2016
merge 1:1 y3_hhid PID using "$IHPS_analysis\hh_mod_c_16.dta", nogen // Education module 

destring y3_hhid, ignore("-") replace
destring y2_hhid, ignore("-") replace
destring PID, replace
format PID  %12.0g

sort ea_id
destring ea_id, replace

bysort y3_hhid: egen hh_size = count(PID)
lab var hh_size "Household size"
numlabel, add

replace hh_b05a = hh_b06_3a if hh_b05a==. // Households that had two visits recorded age in 6_3a as well

******** Generating household labour variables in adult equivalent *********************
// Number of household members by gender 
bysort y3_hhid: egen male_member = count(PID) if hh_b03==1 & hh_b05a>=15
lab var male_member "male member older than 15 years"

bysort y3_hhid: egen fmale_member = count(PID) if hh_b03==2 & hh_b05a>=15
lab var fmale_member "female member older than 15 years"

bysort y3_hhid: egen cmale_member = count(PID) if hh_b03==1 & hh_b05a>5 & hh_b05a<15
lab var cmale_member "child male member less than 15 years but above 5 years"

bysort y3_hhid: egen cfmale_member = count(PID) if hh_b03==2 & hh_b05a>5 & hh_b05a<15
lab var cfmale_member "child female member less than 15 years but above 5 years"

// Labour values in adult equivalent 
****** Number of months the household member was away
rename hh_b07 month_away 
gen month_away_dummy= 1 if month_away==12
replace month_away_dummy=0 if month_away_dummy==. & month_away<12

gen adult_male_lab=1 if hh_b03==1 & hh_b05a>=15 & month_away<12
lab var adult_male_lab "adult equivalent - male labour older than 15 years"

gen adult_fmale_lab =0.8 if hh_b03==2 & hh_b05a>=15 & month_away<12
lab var adult_fmale_lab "adult equivalent - female labour older than 15 years"

gen adult_cmale_lab =0.5 if hh_b03==1 & hh_b05a>5 & hh_b05a<15 & month_away<12
lab var adult_cmale_lab "adult equivalent - male child labour less than 15 years but above 5 years"

gen adult_cfmale_lab =0.5 if hh_b03==2 & hh_b05a>5 & hh_b05a<15 & month_away<12
lab var adult_cfmale_lab "adult equivalent - female child labour less than 15 years but above 5 years"

// Total male labor. For members who were present atleast one month in the year
egen hh_male_labour  = total (adult_male_lab), by (y3_hhid)
replace hh_male_labour=0 if hh_male_labour==.
lab var hh_male_labour "Adult male labour per household"

//total female labour
egen hh_female_labour  = total (adult_fmale_lab), by (y3_hhid)
replace hh_female_labour=0 if hh_female_labour==.
lab var hh_female_labour "Adult female labour per household"

//total male child labour
egen hh_cmale_labour  = total (adult_cmale_lab), by (y3_hhid)
replace hh_cmale_labour=0 if hh_cmale_labour==.
lab var hh_cmale_labour "Adult male child labour per household"

//total female child labour
egen hh_cfmale_labour  = total (adult_cfmale_lab), by (y3_hhid)
replace hh_cfmale_labour=0 if hh_cfmale_labour==.
lab var hh_cfmale_labour "Adult female child labour per household"

// Total number of children 
egen number_children = rowtotal(cmale_member cfmale_member)
egen hh_number_children = max(number_children), by (y3_hhid)
lab var hh_number_children " Total number of children in a household under the age of 15"

// Land to adult male and female labour
egen total_male_fem_labor = rowtotal (hh_male_labour hh_female_labour)
lab var total_male_fem_labor "Total male and female labour for each household"

egen all_hh_labour = rowtotal(hh_male_labour hh_female_labour hh_cmale_labour hh_cfmale_labour)
lab var all_hh_labour " Adult equivalent labour per household"

svyset ea_id [pweight=panelweight_2016], strata(region) singleunit(centered)

***** Gender of household head 2016 *******
svy: tab hh_b03 if hh_b04==1  
notes: 12 households with wife/husband as first variable while 2 with sister/bother

gen relation=1 if hh_b04==1

rename hh_b16a hh_b16 //whereabouts of the father
rename hh_b19a hh_b19 //whereabouts of the mother

rename hh_b16 Father_info
rename hh_b16b Father_id
rename hh_b18 father_high_edu_level
rename hh_b21 mother_high_edu_level
rename hh_b22 language
rename hh_b22_oth other_language
rename hh_b24 Marital_status
rename hh_b24_1 Marriage_custom
rename hh_b24_1_oth Other_marriage_custom
rename hh_b24_2 residence_after_marriage

rename hh_b26a copy_wife_hus_id
rename hh_b26a_1 marriage_year 
rename hh_b26b second_copy_wife_hus_id
rename hh_b26b_1 second_marriage_year
rename hh_b26b_2 spouce_outside_HH
rename hh_b26c third_copy_wife_hus_id
rename hh_b26c_1 third_marriage_year
rename hh_b26c_2 other_spouce_outside_HH

rename hh_c14 why_drop_school
rename hh_c14_oth oth_why_drop_school
rename hh_c18 school_transport 
rename hh_c18_oth other_school_transport

gen edu_head = hh_c08
replace edu_head=0 if edu_head==. & hh_c06==2
// There were missing education variables in section C. 
// I used the education of father or mother for the children in the house
// refer to question mother and father education
egen father_child_quali = mode(father_high_edu_level) if hh_b04==3, by(y3_hhid)
egen father_edu = max(father_child_quali), by(y3_hhid)

egen mother_child_quali = mode(mother_high_edu_level) if hh_b04==3, by(y3_hhid)
egen mother_edu = max(mother_child_quali), by(y3_hhid)

drop father_child_quali mother_child_quali
replace edu_head = father_edu if edu_head==. & hh_b03==1 & relation==1
replace edu_head = mother_edu if edu_head==. & hh_b03==2 & relation==1

*keep if relation==1
 
keep y3_hhid y2_hhid HHID case_id ea_id panelweight_2016 panelweight_2013 hh_wgt ///
region district ta_code reside dist_to_IHS3location dist_to_IHPSlocation hhsize ///
mover hh_a11 hh_g09 hh_m00 hh_o0a hh_s01 hh_w01 consumption_date PID hhmember ///
baselinemember baselinemembercount individualmover moverbasehh ///
interview_status inter_date_v1 inter_date_v2 id_code ///
hh_x10 hh_x10_2015_16 hh_x11 hh_x16 hh_x18 hh_x19 hh_x22 ///
hh_b03 hh_b04 hh_b05a hh_b05b hh_b06_1 hh_b06_2 hh_b06_3a hh_b06_3b hh_b06a ///
hh_b06b month_away hh_b08 hh_b09 hh_b10_oth hh_b10a hh_b10b hh_b11 hh_b12 hh_b13 ///
hh_b13_oth hh_b14 hh_b15a hh_b15b hh_b15b_oth Father_info Father_id hh_b17 father_edu ///
mother_edu language other_language hh_b23 Marital_status Marriage_custom ///
Other_marriage_custom residence_after_marriage hh_b25 ///
copy_wife_hus_id marriage_year second_copy_wife_hus_id second_marriage_year ///
spouce_outside_HH third_copy_wife_hus_id third_marriage_year other_spouce_outside_HH ///
hh_b27 hh_b28 year hh_c02 hh_c03 hh_c04 hh_c05b hh_c06 hh_c07a hh_c07b ///
hh_c07_oth hh_c08 hh_c09 hh_c10 hh_c11 hh_c12 hh_c13 why_drop_school ///
oth_why_drop_school ///
hh_c15 hh_c16 hh_c17 school_transport other_school_transport hh_c19a hh_c19b hh_c20 ///
hh_size male_member fmale_member cmale_member cfmale_member adult_male_lab ///
adult_fmale_lab adult_cmale_lab adult_cfmale_lab all_hh_labour total_male_fem_labor ///
hh_male_labour hh_female_labour hh_number_children relation edu_head month_away_dummy

// Enter rainfall data from Met department in Malawi obtained through Ministry of Agriculture
// This is annual average rainfal (mm) per district in Malawi
numlabel, add
tab district
gen rainfall_14_15=. // for 2014/15 growing season, a year before data collection in 2015/2016
replace rainfall_14_15=863.7 if district==101 // Chitipa 
replace rainfall_14_15=884.5 if district==102 // Karonga
replace rainfall_14_15=1006.7 if district==103 // Nkhata bay
replace rainfall_14_15=734.2 if district==105 // Mzimba
replace rainfall_14_15=1334.8 if district==107 // Mzuzu city. I used Mzuzu airport

replace rainfall_14_15=763.3 if district==201 // Kasungu
replace rainfall_14_15=937.2 if district==202 // Nkhotakota 
replace rainfall_14_15=727.3 if district==203 // Ntchisi, Because it was missing, i used average of Nkhotakota and Dowa
replace rainfall_14_15=541.4 if district==204 // Dowa
replace rainfall_14_15=1336.9 if district==205 // Salima
replace rainfall_14_15=603.8 if district==206 // Lilongwe rural. I used Chitedze for Lilongwe rural
replace rainfall_14_15=821.6 if district==207 // Mchinji
replace rainfall_14_15=819.5 if district==208 // Dedza
replace rainfall_14_15=720.2 if district==209 // Ntcheu
replace rainfall_14_15=880.1 if district==210 // Lilongwe city. I used KIA met here 

replace rainfall_14_15=844.8 if district==301 // Mangochi
replace rainfall_14_15=999.5 if district==302 // Machinga
replace rainfall_14_15=1184.8 if district==303 // Zomba rural. I used Chingale and Makoka stations
replace rainfall_14_15=1610.7 if district==304 // Chiradzulu
replace rainfall_14_15=889.3 if district==305 // Blantyre rural. I used Chileka
replace rainfall_14_15=838.6 if district==306 // Mwanza
replace rainfall_14_15=1082.8 if district==307 // Thyolo
replace rainfall_14_15=1792.1 if district==308 // Mulanje
replace rainfall_14_15=1488.4 if district==309 // Pholombe. I used average fo Zomba and Mulanje
replace rainfall_14_15=1067.7 if district==310 // Chikwawa
replace rainfall_14_15=1910.2 if district==311 // Nsanje
replace rainfall_14_15=1070.8 if district==312 // Balaka
replace rainfall_14_15=1258.0 if district==314 // Zomba city. I used Chancellor college
replace rainfall_14_15=1453.9 if district==315 // Blantyre city. I used Chichiri 

rename rainfall_14_15 rainfall_lag1

gen rainfall_13_14=. // for 2013/14 growing season, two years before data collection in 2015/2016
replace rainfall_13_14=863.7 if district==101 // Chitipa
replace rainfall_13_14=1155.8 if district==102 // Karonga
replace rainfall_13_14=1988.1 if district==103 // Nkhata bay
replace rainfall_13_14=1091.2 if district==105 // Mzimba
replace rainfall_13_14=1480.9 if district==107 // Mzuzu city. I used Mzuzu airport

replace rainfall_13_14=731.3 if district==201 // Kasungu
replace rainfall_13_14=1354.8 if district==202 // Nkhotakota
replace rainfall_13_14=1126.6 if district==203 // Ntchisi. Because it was missing, i used average of Nkhotakota and Dowa
replace rainfall_13_14=727.3 if district==204 // Dowa
replace rainfall_13_14=986.7 if district==205 // Salima
replace rainfall_13_14=737.5 if district==206 // Lilongwe rural. I used Chitedze for Lilongwe rural
replace rainfall_13_14=742.7 if district==207 // Mchinji
replace rainfall_13_14=972.1 if district==208 // Dedza
replace rainfall_13_14=654.7 if district==209 // Ntcheu
replace rainfall_13_14=872.5 if district==210 // Lilongwe city. I used KIA met here 

replace rainfall_13_14=877.4 if district==301 // Mangochi
replace rainfall_13_14=1024.1 if district==302 // Machinga
replace rainfall_13_14=832.5 if district==303 // Zomba rural
replace rainfall_13_14=766.8 if district==304 // Chiradzulu
replace rainfall_13_14=620.1 if district==305 // Blantyre rural. I used Chileka
replace rainfall_13_14=939.4 if district==306 // Mwanza
replace rainfall_13_14=1134.3 if district==307 // Thyolo
replace rainfall_13_14=1949.3 if district==308 // Mulanje
replace rainfall_13_14=1390.9 if district==309 // Pholombe. I used average fo Zomba and Mulanje
replace rainfall_13_14=706.3 if district==310 // Chikwawa
replace rainfall_13_14=763.8 if district==311 // Nsanje
replace rainfall_13_14=466.2 if district==312 // Balaka
replace rainfall_13_14=955.0 if district==314 // Zomba city. I used Chancellor college
replace rainfall_13_14=890.2 if district==315 // Blantyre city. I used Chichiri 

rename rainfall_13_14 rainfall_lag2

gen rainfall_12_13=. // for 2012/13 growing season, three years before data collection in 2015/2016
// But also the year for previous survey round
replace rainfall_12_13=847.1 if district==101 // Chitipa
replace rainfall_12_13=1250.3 if district==102 // Karonga
replace rainfall_12_13=1797.2 if district==103 // Nkhata bay
replace rainfall_12_13=564.9 if district==105 // Mzimba
replace rainfall_12_13=1111.8 if district==107 // Mzuzu city. I used Mzuzu airport 

replace rainfall_12_13=596.4 if district==201 // Kasungu
replace rainfall_12_13=1172.3 if district==202 // Nkhotakota
replace rainfall_12_13=986.7 if district==203 // Ntchisi. Because it was missing, i used average of Nkhotakota and Dowa
replace rainfall_12_13=650.1 if district==204 // Dowa
replace rainfall_12_13=727.3 if district==205 // Salima
replace rainfall_12_13=884.4 if district==206 // Lilongwe rural. I used Chitedze for Lilongwe rural
replace rainfall_12_13=709.9 if district==207 // Mchinji
replace rainfall_12_13=885.6 if district==208 // Dedza
replace rainfall_12_13=1031.4 if district==209 // Ntcheu
replace rainfall_12_13=961.1 if district==210 // Lilongwe city. I used KIA met here 

replace rainfall_12_13=789.3 if district==301 // Mangochi
replace rainfall_12_13=919.9 if district==302 // Machinga
replace rainfall_12_13=819.8 if district==303 // Zomba rural
replace rainfall_12_13=769.5 if district==304 // Chiradzulu
replace rainfall_12_13=935.6 if district==305 // Blantyre rural. I used Chileka
replace rainfall_12_13=1132.7 if district==306 //  Mwanza
replace rainfall_12_13=1212.5 if district==307 // Thyolo
replace rainfall_12_13=2074.1 if district==308 // Mulanje
replace rainfall_12_13=1447.0 if district==309 // Pholombe. I used average fo Zomba and Mulanje
replace rainfall_12_13=796.0 if district==310 // Chikwawa
replace rainfall_12_13=1045.4 if district==311 // Nsanje
replace rainfall_12_13=464.2 if district==312 // Balaka
replace rainfall_12_13=1308 if district==314 // Zomba city. I used Chancellor college
replace rainfall_12_13=1266.6 if district==315 // Blantyre city. I used Chichiri 

rename rainfall_12_13 rainfall_lag3

save "$temp_file_2016\hh_mod_abc_16", replace

********** Working with Time use and labour ***********************
use "$IHPS_analysis\hh_mod_e_16.dta", clear
destring y3_hhid, ignore("-") replace
destring PID, replace
format %20.0g PID 
keep y3_hhid qx_type interview_status PID id_code hh_e03 ///
hh_e04 hh_e05 hh_e06 hh_e06_1a hh_e06_1b hh_e06_1c hh_e06_2 ///
hh_e06_3 hh_e06_4 hh_e06_5 hh_e06_6 hh_e06_8a hh_e06_8b ///
hh_e07_1_1 hh_e07_1_2 hh_e07_1_3 hh_e07_1_4 hh_e07_1_5 hh_e07_1a ///
hh_e07_1b hh_e07_1c hh_e07_1oth hh_e07_2a hh_e07_2b hh_e07_2c ///
hh_e07_3a hh_e07_3b hh_e07_3c hh_e07_4a hh_e07_4b hh_e07_4c ///
hh_e07_5a hh_e07_5b hh_e07_5c hh_e07a hh_e07b hh_e07c hh_e08 ///
hh_e09 hh_e10 hh_e11 hh_e12 hh_e13_1a hh_e13_1b hh_e14 hh_e15 ///
hh_e15_oth hh_e16 hh_e17

merge 1:1 y3_hhid PID using "$temp_file_2016\hh_mod_abc_16", nogen

********** Generating number of household members engaged in off farm activities 

// Agriculture farm work by individual member
bysort y3_hhid: egen PID_agri_work = count(PID) if hh_e06_1a==1
egen hh_cropfarm_work = max(PID_agri_work), by(y3_hhid)

bysort y3_hhid: egen PID_livestock_work = count(PID) if hh_e06_1b==1
egen hh_livefarm_work = max(PID_livestock_work), by(y3_hhid)

bysort y3_hhid: egen PID_fisheries_work = count(PID) if hh_e06_1c==1
egen hh_fishfarm_work = max(PID_fisheries_work), by(y3_hhid)

egen hh_agrifarm_work = rowmax(hh_cropfarm_work hh_livefarm_work hh_fishfarm_work)
replace hh_agrifarm_work=0 if hh_agrifarm_work==.
lab var hh_agrifarm_work "Number of hh members engaged in agriculture farm work by individuals"
drop PID_agri_work PID_livestock_work PID_fisheries_work

// Non farm own business by individual member
bysort y3_hhid: egen PID_own_business = count(PID) if hh_e06_2==1
egen hh_nonfarm_own_business = max(PID_own_business), by(y3_hhid)
replace hh_nonfarm_own_business=0 if hh_nonfarm_own_business==.
lab var hh_nonfarm_own_business "Number of hh members engaged in non farm business by individuals"
drop PID_own_business 

// Non farm business for the household 
bysort y3_hhid: egen PID_hh_business = count(PID) if hh_e06_3==1
egen hh_nonfarm_hh_business = max(PID_hh_business), by(y3_hhid)
replace hh_nonfarm_hh_business=0 if hh_nonfarm_hh_business==.
lab var hh_nonfarm_hh_business "Number of hh members engaged in non farm business for the household"
drop PID_hh_business

// Work for wage, salary, commission or any payment in kind excluding ganyu 
bysort y3_hhid: egen PID_longterm_employment = count(PID) if hh_e06_4==1
egen hh_longterm_employment = max(PID_longterm_employment), by(y3_hhid)
replace hh_longterm_employment=0 if hh_longterm_employment==.
lab var hh_longterm_employment "Work as employment for wage but excludidng ganyu at household level"
drop PID_longterm_employment

// Un paid apprenticeship excluding ganyu 
bysort y3_hhid: egen PID_unpaid_apprenticeship = count(PID) if hh_e06_5==1
egen hh_unpaid_apprenticeship = max(PID_unpaid_apprenticeship), by(y3_hhid)
replace hh_unpaid_apprenticeship=0 if hh_unpaid_apprenticeship==.
lab var hh_unpaid_apprenticeship "Unpaid apprenticeship but excludidng ganyu at household level"
drop PID_unpaid_apprenticeship

// Ganyu work 
bysort y3_hhid: egen PID_ganyu = count(PID) if hh_e06_6==1
egen hh_ganyu = max(PID_ganyu), by(y3_hhid)
replace hh_ganyu=0 if hh_ganyu==.
lab var hh_ganyu "Engage in casual, part time or ganyu at household level"
drop PID_ganyu

******** Keeping for household head only 
local uselabour "hh_e06_1a hh_e06_1b hh_e06_1c hh_e06_2 hh_e06_3 hh_e06_4 hh_e06_5 hh_e06_6" 
foreach var of local uselabour {
recode `var' (2=0)
label define `var' 0 "No" 1 "Yes", modify
label val `var' `var'
}
egen hh_head_offfarm=rowmax (hh_e06_2 hh_e06_3 hh_e06_4 hh_e06_5 hh_e06_6)
lab define dummy 0"No" 1"Yes"
lab values hh_head_offfarm dummy

// Generate adult equivalent labour used off their own farms

gen adultEqui_male_ganyu = adult_male_lab if hh_e06_6==1
gen adultEqui_fmale_ganyu = adult_fmale_lab if hh_e06_6==1
gen adultEqui_cmale_ganyu = adult_cmale_lab if hh_e06_6==1
gen adultEqui_cfmale_ganyu = adult_cfmale_lab if hh_e06_6==1

egen row_adulEqiva_ganyu = rowtotal (adultEqui_male_ganyu adultEqui_fmale_ganyu adultEqui_cmale_ganyu adultEqui_cfmale_ganyu)
egen adulEquiv_hh_ganyu = total (row_adulEqiva_ganyu), by(y3_hhid)

keep if relation==1
count

save "$temp_file_2016\labour_use_16.dta", replace



********************************************************************
*********** Working with Shocks and Coping strategies 2016 *********
use "$IHPS_analysis\hh_mod_u_16.dta", clear
destring y3_hhid, ignore("-") replace
reshape wide hh_u01 hh_u02 hh_u03a hh_u03b hh_u03c hh_u03d hh_u03e hh_u04a hh_u04b hh_u04c, i(y3_hhid) j(hh_u0a)
local count 0
foreach v of var hh_u011* {
lab var `v' "`++count' During the last 12 months, was your HH affected negatively by any shocks"
}
*****
local count 0
foreach v of var hh_u02* {
lab var `v' "`++count' Rank the three most significant shocks you experienced"
}
*****
local count 0
foreach v of var hh_u03a* {
lab var `v' "`++count' As a result of this [SHOCK], did your income..."
}
*****
local count 0
foreach v of var hh_u03b* {
lab var `v' "`++count' As a result of this [SHOCK], did your assets..."
}
*****
local count 0
foreach v of var hh_u03c* {
lab var `v' "`++count' As a result of this [SHOCK], did your food production..."
}
*****
local count 0
foreach v of var hh_u03d* {
lab var `v' "`++count' As a result of this [SHOCK], did your food stocks..."
}
*****
local count 0
foreach v of var hh_u03e* {
lab var `v' "`++count' As a result of this [SHOCK], did your food stocks..."
}
*****
local count 0
foreach v of var hh_u04a* {
lab var `v' "`++count' Interventions to try to regain your former welfare level? (1)"
}
*****
local count 0
foreach v of var hh_u04b* {
lab var `v' "`++count' Interventions to try to regain your former welfare level? (2)"
}
*****
local count 0
foreach v of var hh_u04c* {
lab var `v' "`++count' Interventions to try to regain your former welfare level? (3)"
}
*****

rename hh_u01101 Drought
rename hh_u01102 Floods
rename hh_u01103 Earthquakes
rename hh_u01104 Unusual_crop_pest_disease
rename hh_u01105 Unusual_livestock_disease
rename hh_u01106 Unusual_low_output_prices
rename hh_u01107 Unusual_high_input_prices
rename hh_u01108 Unusual_high_food_prices
rename hh_u01109 End_regular_assistance_aid
rename hh_u01110 Lowbusinesincome_notfrom_illnes
rename hh_u01111 Businesfailure_notfrom_illnes
rename hh_u01112 Lowworkincome_notfrom_illnes
rename hh_u01113 Jobloss_notfrom_illnes 
rename hh_u01114 Serious_illness_accident
rename hh_u01115 Child_birth
rename hh_u01116 Death_income_earner
rename hh_u01117 Death_other_HHmember
rename hh_u01118 Theft
rename hh_u01119 Household_break_up
rename hh_u01120 Conflict_violence
rename hh_u01121 Others_specify
rename hh_u011101 Irregular_rains
rename hh_u04c1102 Landslides

save "$temp_file_2016\drought_16.dta", replace

****** Merging with geo-referenced data variables *******************
use "$IHPS_analysis\HouseholdGeovariablesIHPSY3.dta", clear
destring y3_hhid, ignore("-") replace
encode popdensity, gen (popu_density)
tab popu_density
recode popu_density (1=100) (2=101) (3=102) (4=103) (5=104) (6=105) ///
(7=106) (8=107) (9=108) (10=109) (11=110)
recode popu_density (100=1) (108=2) (101=3) (103=4) (105=5) (107=6) (109=7) ///
(102=8) (104=9) (106=10) (110=11)
lab define density 1"0-50" 2"50-100" 3"100-200" 4"200-300" 5"300-400" ///
6"400-500" 7"500-1000" 8"1000-2000" 9"2000-3000" 10"3000-5000" 11">5000"
lab values popu_density density 
numlabel, add
tab popu_density
drop if popu_density==. & anntot_avg==.
save "$temp_file_2016\geo_variables_2016hh.dta", replace

***************************************************************************
********** Asset wealth for 2016 ********************************
use "$IHPS_analysis\hh_mod_l_16.dta", clear
destring y3_hhid, ignore ("-") replace
format y3_hhid %20.0g
gen total_item_cost = hh_l03* hh_l05
lab var total_item_cost "Total cost for all items"
egen total_hh_goods_wealth =total(total_item_cost), by (y3_hhid)
lab var total_hh_goods_wealth "Total cost for all durable items at household"

recode hh_l01 (2=0)
lab define dummy 0"NO" 1"YES"
lab values hh_l01 dummy

reshape wide hh_l01 hh_l03 hh_l04 hh_l05 hh_l06 hh_l07 total_item_cost, i(y3_hhid) j(hh_l02)

isid y3_hhid
count 
save "$temp_file_2016\hh_mod_L_16.dta", replace 

use "$IHPS_analysis\hh_mod_m_16.dta", clear
destring y3_hhid, ignore ("-") replace
format y3_hhid %20.0g
gen all_item_cost = hh_m01*hh_m03
lab var all_item_cost "Total cost for all items"
egen total_hh_farm_wealth =total(all_item_cost), by (y3_hhid)
lab var total_hh_farm_wealth "Total cost for all farm equipment at household"

replace hh_m0c=2 if hh_m00==2 & hh_m0c==.
recode hh_m0c (2=0)
lab define dummy 0"NO" 1"YES"
lab values hh_m0c dummy
reshape wide hh_m00 hh_m0b_oth hh_m0c hh_m01 hh_m02 hh_m03 hh_m04 hh_m05 hh_m06 hh_m08 hh_m09 hh_m10 hh_m11 hh_m11_oth hh_m12 hh_m13 hh_m14 all_item_cost,i(y3_hhid) j(hh_m0b) 

// Assessing the asset ownership dummy
tab hh_m0c601
tab hh_m0c602
tab hh_m0c603
tab hh_m0c604
**********************************************************
************** Merging with module L **********************
merge 1:1 y3_hhid using "$temp_file_2016\hh_mod_L_16.dta", nogen

// Factor analysis  
* variable L01 range for factor analysis: 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 5081
*variable M01 range for factor analysis: 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625
******************PCA****************************************
factor hh_l01* hh_m0c*
predict capital_asset_score

drop hh_l01* hh_l03* hh_l04* hh_l05* hh_l06* hh_l07* total_item_cost* ///
hh_m00* hh_m0b_oth* hh_m0c* hh_m01* hh_m02* hh_m03* hh_m04* hh_m05* hh_m06* hh_m08* hh_m09* hh_m10* hh_m11* hh_m11_oth* hh_m12* hh_m13* hh_m14* all_item_cost* 

gen total_asset_value = total_hh_farm_wealth + total_hh_goods_wealth
lab var total_asset_value "Total asset value at household level"
*sort case_id 
*quietly by case_id : gen dup = cond(_N==1,0,_n)  
*tab dup
*drop if dup>1
*drop dup
isid y3_hhid
count 
save "$temp_file_2016\hh_mod_L_M_16.dta", replace 
****************************************************************************

use "$temp_file_2016\labour_use_16.dta", clear
merge 1:1 y3_hhid using "$temp_file_2016\geo_variables_2016hh.dta", nogen
merge 1:1 y3_hhid using "$temp_file_2016\drought_16.dta", nogen
merge 1:1 y3_hhid using "$temp_file_2016\hh_mod_L_M_16.dta", nogen 
isid y3_hhid
save "$temp_file_2016\hh_mod_abceulm_geo_16", replace


******** working livestock units 2016 *******************
use "$IHPS_analysis\ag_mod_r1_16.dta", clear
destring y3_hhid,ignore("-") replace

keep y3_hhid ag_r00 ag_r0a ag_r01 ag_r01_oth ag_r01_1a ///
ag_r01_1b ag_r01_1_oth ag_r02 ag_r02_1 ag_r02_2 ag_r02_2_oth ///
ag_r03 ag_r03_2 ag_r03_2_oth ag_r04 ag_r07 ag_r08
reshape wide ag_r01 ag_r01_oth ag_r01_1a ag_r01_1b ag_r01_1_oth ///
ag_r02 ag_r02_1 ag_r02_2 ag_r02_2_oth ag_r03 ag_r03_2 ///
ag_r03_2_oth ag_r04 ag_r07 ag_r08, i(y3_hhid) j (ag_r0a)

rename (ag_r01301 ag_r01302 ag_r01303 ag_r01304 ag_r01307 ag_r01308 ag_r01309 ///
ag_r01311 ag_r01313 ag_r01315 ag_r01319 ag_r013304 ag_r013305 ag_r013310 ag_r013314) ///
(cattle steer_heifer cow bull goat sheep pig local_hen local_cock duck dove_pigeon ///
ox donkey_mule_horse chicken_layer_chicken_broiler turkey_guinea_fowl)

**** Calculating Total Livestock Units 2016 **************
gen TLU_donkey=ag_r023305*0.8 // measures for sub-saharan region 
gen TLU_cattle=ag_r02301*0.5 
gen TLU_steer =ag_r02302*.3 // based on europe because of no figures in SSA
gen TLU_cow=ag_r02303*0.5 
gen TLU_bull=ag_r02304*0.5 
gen TLU_ox=ag_r023304*0.1 
gen TLU_goat=ag_r02307*0.1
gen TLU_sheep=ag_r02308*0.1 
gen TLU_pig=ag_r02309*0.2 
gen TLU_loacl_hen=ag_r02311*0.01 
gen TLU_loacl_cock=ag_r02313*0.01 
gen TLU_duck=ag_r02315*0.03
gen TLU_dove_pigeon=ag_r02319*0.1
gen TLU_chicken_broiler=ag_r023310*0.1 
 
egen total_TLU=rowtotal (TLU_donkey TLU_cattle TLU_cow TLU_bull ///
TLU_sheep TLU_goat TLU_pig TLU_loacl_hen TLU_loacl_cock ///
TLU_duck TLU_dove_pigeon TLU_chicken_broiler)

**** Gen lag TLU 2016 **************************
gen lag_TLU_donkey=ag_r073305*0.8 // measures for sub-saharan region 
gen lag_TLU_cattle=ag_r07301*0.5 
gen lag_TLU_steer =ag_r07302*.3 // based on europe because of no figures in SSA
gen lag_TLU_cow=ag_r07303*0.5 
gen lag_TLU_bull=ag_r07304*0.5 
gen lag_TLU_ox=ag_r073304*0.1 
gen lag_TLU_goat=ag_r07307*0.1
gen lag_TLU_sheep=ag_r07308*0.1 
gen lag_TLU_pig=ag_r07309*0.2 
gen lag_TLU_loacl_hen=ag_r07311*0.01 
gen lag_TLU_loacl_cock=ag_r07313*0.01 
gen lag_TLU_duck=ag_r07315*0.03
gen lag_TLU_dove_pigeon=ag_r07319*0.1
gen lag_TLU_chicken_broiler=ag_r073310*0.1 
 
egen lag_total_TLU=rowtotal (lag_TLU_sheep lag_TLU_pig lag_TLU_loacl_hen ///
lag_TLU_loacl_cock lag_TLU_duck lag_TLU_dove_pigeon lag_TLU_chicken_broiler)

keep y3_hhid cattle ag_r02301 ag_r07301 steer_heifer ag_r02302 ///
ag_r07302 cow ag_r02303 ag_r07303 bull ag_r02304 ag_r07304 ///
goat ag_r02307 ag_r07307 sheep ag_r02308 ag_r07308 pig ///
ag_r02309 ag_r07309 local_hen ag_r02311 ag_r07311 local_cock ///
ag_r02313 ag_r07313 duck ag_r02315 ag_r07315 ag_r01318 ///
ag_r02318 ag_r07318 dove_pigeon ag_r02319 ag_r07319 ox ///
ag_r023304 ag_r073304 donkey_mule_horse ag_r023305 ag_r073305 ///
chicken_layer_chicken_broiler ag_r023310 ag_r073310 ///
turkey_guinea_fowl ag_r023314 ag_r073314 TLU_donkey ///
TLU_cattle TLU_steer TLU_cow TLU_bull TLU_ox TLU_goat ///
TLU_sheep TLU_pig TLU_loacl_hen TLU_loacl_cock TLU_duck ///
TLU_dove_pigeon TLU_chicken_broiler total_TLU lag_TLU_donkey ///
lag_TLU_cattle lag_TLU_steer lag_TLU_cow lag_TLU_bull ///
lag_TLU_ox lag_TLU_goat lag_TLU_sheep lag_TLU_pig ///
lag_TLU_loacl_hen lag_TLU_loacl_cock lag_TLU_duck ///
lag_TLU_dove_pigeon lag_TLU_chicken_broiler lag_total_TLU

isid y3_hhid
save "$temp_file_2016\TLU_2016.dta", replace


**************** Household and livestock **********************
********* Merging Household and Livestock 2016 ********
use "$temp_file_2016\hh_mod_abceulm_geo_16", clear
merge 1:1 y3_hhid using "$temp_file_2016\TLU_2016.dta", nogen
********* Because of the filter question of livestock, some households were missing
// in livestock module so i had to match a No response in question hh_s01 to be zero 
// in the total TLU variable so that i dont drop observations
replace total_TLU=0 if hh_s01==2 & total_TLU==.
replace lag_total_TLU=0 if hh_s01==2 & lag_total_TLU==.
**If a household said yes in hh_s01 but zero current or one year lag stock
// that household is considered zero for current TLU or lag TLU
replace total_TLU=0 if hh_s01==1 & total_TLU==.
replace lag_total_TLU=0 if hh_s01==1 & lag_total_TLU==.

save "$temp_file_2016\hh_mod_abceulm_geo_r_16.dta", replace 

*************************************************************

***** Agriculture modules in 2016 ***********************
***** parcel level data 2016 ************************* 
use "$IHPS_analysis\ag_mod_a_16.dta", clear //  Household filter 
merge 1:m y3_hhid using "$IHPS_analysis\ag_mod_b1_16.dta" //Rainy season garden roster
notes: 590 households did not do any crop farming on land. We maintain all HHs
rename _merge merge1
merge 1:1 y3_hhid gardenid using "$IHPS_analysis\ag_mod_b2_16.dta" // Rainy season garden details 
rename _merge merge2

encode gardenid, gen (parcel_id)
destring y3_hhid, ignore ("-") replace
format y3_hhid %12.0g
numlabel, add
tab parcel_id 

drop if parcel_id==. // Non-agricultural households 
isid y3_hhid parcel_id

rename ag_b104a2 ag_bl04c
rename ag_b105c ag_b105e
drop gardenid merge1 merge2

encode ag_b203_oth, gen (other_land_sources)
numlabel, add
tab ag_b203 
tab other_land_sources
recode other_land_sources (1=100) (2=101) (3=102) (4=103) (5=104) (6=105) (7=106) ///
(8=107) (9=108) (10=109) (11=110) (12=111) (13=112)
recode other_land_sources (100=9) (101=8) (102=12) (103=9) (104=9) (105=13) ///
(106=12) (107=11) (108=13) (109=10) (110=11) (111=4) (112=4)
lab define source 1"GRANTED BY LOCAL LEADERS" 2"INHERITED BY THE DEATH OF A FAMILY M" ///
3"BRIDE PRICE" 4"PURCHASED" 5"PURCHASED WITHOUT TITLE" 6"LEASEHOLD" 7"RENT SHORT-TERM" ///
8"FARMING AS A TENANT" 9"BORROWED FOR FREE" 10"MOVED IN WITHOUT PERMISSION" ///
11"OTHER (SPECIFY)" 12"ALLOCATED BY FAMILY MEMBER" 13" GIFT FROM NON-HOUSEHOLD MEMBER"
lab values other_land_sources source
numlabel, add
tab other_land_sources

replace ag_b203=other_land_sources if ag_b203==11 & other_land_sources!=.
tab ag_b203
isid y3_hhid parcel_id

save "$temp_file_2016\ag_mod_ab_16.dta", replace


******* working with plot level data 2016 *******************
use "$IHPS_analysis\ag_mod_c_16.dta", clear
merge 1:1 y3_hhid gardenid plotid using "$IHPS_analysis\ag_mod_d_16.dta", nogen

destring y3_hhid, ignore ("-") replace
format y3_hhid %12.0g
encode gardenid, gen(parcel_id)
encode plotid, gen (plot_id)

numlabel, add
tab parcel_id
tab plot_id 

recode plot_id (1=100) (2=101) (3=102) (4=103) (5=104) (6=105) (7=106) (8=107) (9=108) ///
(10=109) (11=110) 
recode plot_id (100=1) (101=10) (102=11) (103=2) (104=3) (105=4) (106=5) (107=6) (108=7) ///
(109=8) (110=9) 
lab define plot1 1"R01" 2"R02" 3"R03" 4"R04" 5"R05" 6"R06" 7"R07" 8"R08" 9"R09" ///
10"R010" 11"R011"
lab values plot_id plot1
numlabel, add
tab parcel_id
tab plot_id

drop if plot_id==.

isid y3_hhid parcel_id plot_id
save "$temp_file_2016\ag_mod_cd_16.dta", replace 


********************************************************************************
******** Looking at Plot geo-referenced data
use "$IHPS_analysis\PlotGeovariablesIHPSY3_16", clear 
destring y3_hhid, ignore ("-") replace
format y3_hhid %12.0g
encode gardenid, gen(parcel_id)
encode plotid, gen (plot_id)
numlabel, add
tab parcel_id
tab plot_id

recode parcel_id (1=100) (2=101) (3=102) (4=103) (5=104) (6=105) (7=106) ///
(8=109) (9=110) (10=111) (11=112) (12=113)
recode parcel_id (102=1) (103=2) (104=3) (105=4) (106=5) ///
(109=6) (110=7) (111=200) (112=201) (113=202)
label define parcel 1 "RG01" 2 "RG02" 3 "RG03" 4 "RG04" 5 "RG05" 6 "RG06" ///
7 "RG07" 100"DG01" 101"DG02" 200"TG01" 201"TG02" 202"TG03"
lab values parcel_id parcel

recode plot_id (1=1000) (2=1010) (3=1020) (4=1030) (5=1040) (6=1050) (7=1060) (8=1070) (9=1080) ///
(10=1090) (11=1100) (12=1110) (13=1120) (14=1130) (15=1140) (16=1150) (17=1160) (18=1170) ///
(19=1180) (20=1190) (21=1200) (22=1210) (23=1220) (24=1230) (25=1240)

recode plot_id (1000=101) (1010=102) (1020=103) (1030=104) (1040=105) (1050=1) ///
(1060=10) (1070=11) (1080=2) (1090=3) (1100=4) (1110=5) (1120=6) (1130=7) ///
(1140=8) (1150=9) (1160=201) (1170=202) (1180=203) (1190=204) (1200=205) (1210=206) ///
(1220=207) (1230=208) (1240=209)
lab define geoplot 1"R01" 2"R02" 3"R03" 4"R04" 5"R05" 6"R06" 7"R07" 8"R08" 9"R09" ///
10"R010" 11"R011" 101"D01" 102"D02" 103"D03" 104"D04" 105"D05" 106"D06" 201"T01" ///
202"T02" 203"T03" 204"T03" 205"T05" 206"T06" 207"T07" 208"T07" 209"T09"
lab values plot_id geoplot

numlabel, add
tab parcel_id
tab plot_id
drop if parcel_id==.
drop if plot_id==.
isid y3_hhid parcel_id plot_id
replace twi = "." in 1306
destring twi, replace
*keep if plot_id<100 // This drops dimba and forest tree plots 
merge 1:1 y3_hhid parcel_id plot_id using "$temp_file_2016\ag_mod_cd_16.dta"
save "$temp_file_2016\ag_mod_cd_plotgeo_16.dta",replace

************************************************************
use "$temp_file_2016\ag_mod_cd_plotgeo_16.dta", clear 

keep y3_hhid gardenid dist_hh slope elevation twi parcel_id ///
plot_id ag_c04a ag_c04b ag_c04b_oth ag_c04c ag_c05e ag_c05e_oth ag_d01 ///
ag_d01_1 ag_d01_2a ag_d01_2b ag_d02 ag_d14 ag_d21 ///
///
ag_d47a1 ag_d47b1 ag_d47a2 ag_d47b2 ag_d47a3 ag_d47b3 ag_d47c ///
ag_d47d ag_d47d_oth ag_d47e ag_d47f ag_d47f_oth ag_d48a1 ag_d48b1 ///
ag_d48a2 ag_d48b2 ag_d48a3 ag_d48b3 ag_d48c ag_d48d ag_d48d_oth ag_d48e ///
ag_d48f ag_d48f_oth ag_d52a ag_d52b ag_d52c ag_d53a ag_d53b ag_d53c ///
ag_d54a ag_d54b ag_d54c ag_d55_1 ag_d55_2 ag_d55_2oth ag_d55a ag_d55b ag_d55c 

egen hired_farm_labour = rowmax (ag_d47a1 ag_d47a2 ag_d47a3 ag_d48b1 ag_d48b2 ///
ag_d48b3)
gen hh_hired_farmlabour =1 if hired_farm_labour>0
replace  hh_hired_farmlabour=0 if hh_hired_farmlabour==.

egen exchange_farm_labour = rowmax (ag_d52a ag_d52b ag_d52c ag_d54a ag_d54b ag_d54c)
gen hh_exchange_in_farmlabour =1 if exchange_farm_labour>0
replace  hh_exchange_in_farmlabour=0 if hh_exchange_in_farmlabour==.

drop ag_d47a1 ag_d47b1 ag_d47a2 ag_d47b2 ag_d47a3 ag_d47b3 ag_d47c ///
ag_d47d ag_d47d_oth ag_d47e ag_d47f ag_d47f_oth ag_d48a1 ag_d48b1 ///
ag_d48a2 ag_d48b2 ag_d48a3 ag_d48b3 ag_d48c ag_d48d ag_d48d_oth ag_d48e ///
ag_d48f ag_d48f_oth ag_d52a ag_d52b ag_d52c ag_d53a ag_d53b ag_d53c ///
ag_d54a ag_d54b ag_d54c ag_d55_1 ag_d55_2 ag_d55_2oth ag_d55a ag_d55b ag_d55c 

collapse (max) dist_hh slope elevation twi (sum) ag_c04a (firstnm) ag_c04b ag_c04b_oth ///
(sum) ag_c04c (firstnm) ag_c05e ag_c05e_oth ag_d01 ag_d01_1 ag_d01_2a ag_d01_2b ag_d02 ///
ag_d14 ag_d21 hh_hired_farmlabour hh_exchange_in_farmlabour , by (y3_hhid parcel_id)

lab define units 1"ACRE" 2"HECTARE" 3"SQUARE METERS" 4"OTHER (SPECIFY)"
lab values ag_c04b units
lab define gps_reason 1"LONG DISTANCE WITHIN THIS DISTRICT" 2"LONG DISTANCE OUTSIDE THIS DISTRICT" ///
3"HOUSEHOLD REFUSED" 4"OTHER (SPECIFY)"
lab values ag_c05e gps_reason
lab define y_N 1"YES" 0"NO"
recode ag_d01_1 (2=0)
lab values ag_d01_1 y_N
lab values hh_hired_farmlabour y_N
lab values hh_exchange_in_farmlabour y_N
lab define usage 1"Cultivated" 2"Rented out" 3"Gave out for free" 4"Fallow" ///
5"Forest / Woodlot" 6"Pasture" 7"Other (Specify)"
lab values ag_d14 usage  
lab define soil 1"Sandy (Mchenga)" 2"Between sandy & clay(Pakati pa mchen" 3"Clay (Katondo)" ///
4" Other (Specify)"
lab values ag_d21 soil

save "$temp_file_2016\ag_collapsed_cd_plotgeo_16.dta", replace 


********* Merging parcel and plot level data 2016 ******************
use "$temp_file_2016\ag_mod_ab_16.dta", clear
merge 1:1 y3_hhid parcel_id using "$temp_file_2016\ag_collapsed_cd_plotgeo_16.dta"
drop _merge
********* Renaming all variables that might conflict when reshaped *************
rename ag_bl04c ag_b104c // The first one had L instead of 1
rename ag_b103_1 parcel_cultivated
rename ag_b104b_oth other_area_unit
rename ag_b106a gps_record
rename ag_b203 land_source
rename ag_b204_1 land_title
rename ag_b204_3 informal_land_title
rename ag_b204_4b_filter outside_land_owner
rename ag_b205 land_sell_price
rename ag_b206 rent_land_price
rename ag_b210a crop_type
rename ag_b210c rent_price_unit
rename ag_b212b rent_payment_period
rename ag_b218a rent_recieved
rename ag_c04b land_area_unit
rename ag_c05e no_gps_reason
rename ag_d01 parcel_decision_maker
rename ag_b214 land_usage
rename ag_b218c_oth other_unit_rent_recieved
rename twi wetness_index 

recode ag_b204_9 (2=0)
label values ag_b204_9 yesno

reshape wide parcel_cultivated  ag_b101 ag_i101b ag_s01 ag_b103_1a ag_b103_2 ag_b104a ag_b104b other_area_unit ag_b104c ///
ag_b105e ag_b105c_oth ag_b106 gps_record ag_b107 ag_b202 land_source ag_b203_1a ///
ag_b203_1b ag_b203_2 ag_b203_oth other_land_sources land_title ag_b204_1oth ag_b204_2a_1 ///
ag_b204_2__0 ag_b204_2__1 ag_b204_2__2 ag_b204_2__3 ag_b204_2b__0 ///
ag_b204_2b__1 ag_b204_2filter informal_land_title ag_b204_3_oth ag_b204_3_1 ///
ag_b204_4__0 ag_b204_4__1 ag_b204_4__2 ag_b204_4__3 outside_land_owner ///
ag_b204_4b__0 ag_b204_4b__1 ag_b204_5 ag_b204_6__0 ag_b204_6__1 ag_b204_6__2 ///
ag_b204_6__3 ag_b204_6b_filter ag_b204_6b__0 ag_b204_6b__1 ag_b204_7 ///
ag_b204_8__0 ag_b204_8__1 ag_b204_8__2 ag_b204_8__3 ag_b204_8filter ///
ag_b204_8b__0 ag_b204_8b__1 ag_b204_9 ag_b204a__0 ag_b204a__1 ag_b204a__2 ///
ag_b204a__3 ag_b204b ag_b204b__0 ag_b204b__1 land_sell_price rent_land_price ag_b206a ///
ag_b206b__0 ag_b206b__1 ag_b206b__2 ag_b206b__3 ag_b206c ag_b206d__0 ///
ag_b206d__1 crop_type ag_b210a_oth ag_b210b rent_price_unit ag_b210c_oth ag_b210d ///
ag_b211a ag_b211b ag_b211c ag_b211d rent_payment_period ag_b212b_oth ag_b213_1__0 ///
ag_b213_1__1 ag_b213__0 ag_b213__1 land_usage ag_b214_oth rent_recieved ag_b218a_oth ///
ag_b218b ag_b218c other_unit_rent_recieved ag_b218d ag_b219a ag_b219b ag_b219c ag_b219d ///
dist_hh slope elevation wetness_index ag_c04a land_area_unit ag_c04b_oth ag_c04c no_gps_reason ///
ag_c05e_oth parcel_decision_maker ag_d01_1 ag_d01_2a ag_d01_2b ag_d02 ag_d14 ag_d21 ///
hh_hired_farmlabour hh_exchange_in_farmlabour qx_type interview_status, i(y3_hhid) j(parcel_id)

save "$temp_file_2016\ag_mod_abcd_plotgeo_16.dta", replace 


******** Merging household and parcel agriculture data 2016*************
use "$temp_file_2016\hh_mod_abceulm_geo_r_16.dta", clear
merge 1:1 y3_hhid using "$temp_file_2016\ag_mod_abcd_plotgeo_16.dta", nogen
merge m:1 district using "$rain_appended_file\rainfall data 2016.dta"
drop if _merge==2 // These two districts (Rumphi and Neno) are not represented in 2016
isid y3_hhid
count

save "$appended_data\hh_ag_rainy_shock_merged_16", replace
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
*
********* Working with 2013 data ***************************************
use "$IHPS_analysis\hh_mod_a_filt_13.dta", clear
merge 1:1 y2_hhid using "$IHPS_analysis\hh_mod_x_13.dta", nogen
rename hh_x10 hh_x10_2012_13 
count
replace hh_a23a_1=1 if hh_a23a_1==. // Only the date was mising and since the focus 
// is on the month, i replace the missing date with 1 to be able to generate 
// the interview date
numdate daily inter_date_v1 = hh_a23a_1 hh_a23a_2 hh_a23a_3, pattern(DMY)
numdate daily inter_date_v2 = hh_a37a_1 hh_a37a_2 hh_a37a_3, pattern(DMY)
lab var inter_date_v1 "Interview Date Visit 1"
lab var inter_date_v2 "Interview Date Visit 2"

** Dropping interview date and enumerator variables because they are not needed here
drop hh_a23a_1 hh_a23a_2 hh_a23a_3 hh_a23a_4 hh_a23a_5 hh_a23a_6 hh_a23a_7 ///
hh_a23a_8 hh_a23b_1 hh_a23b_2 hh_a23b_3 hh_a23b_5 hh_a23b_4 hh_a23b_6 ///
hh_a23b_7 hh_a23b_8 hh_a23c_1 hh_a23c_2 hh_a23c_3 hh_a23c_4 hh_a23c_5 ///
hh_a23c_6 hh_a23c_7 hh_a23c_8 hh_a24 hh_a26a hh_a26b hh_a26c hh_a27 hh_a29a ///
hh_a29b hh_a29c hh_a30 hh_a33 hh_a35 hh_a37a_1 hh_a37a_2 hh_a37a_3 hh_a37a_4 ///
hh_a37a_5 hh_a37a_6 hh_a37a_7 hh_a37a_8 hh_a37b_1 hh_a37b_2 hh_a37b_3 hh_a37b_4 ///
hh_a37b_5 hh_a37b_6 hh_a37b_7 hh_a37b_8 hh_a38 hh_a40a hh_a40b hh_a40c hh_a41 ///
hh_a43 hh_a43a hh_a43b hh_a43c hh_a44 hh_a46a hh_a46b hh_a46c 

merge 1:m y2_hhid using "$IHPS_analysis\hh_mod_b_13.dta", nogen
gen year=2013 
merge 1:1 y2_hhid PID using "$IHPS_analysis\hh_mod_c_13.dta",nogen
destring y2_hhid, ignore("-") replace
destring PID, replace
format PID  %12.0g

sort ea_id
destring ea_id, replace

bysort y2_hhid: egen hh_size = count(PID)
lab var hh_size "Household size"
numlabel, add

replace hh_b05a = hh_b06_3a if hh_b05a==. // Households that had two visits recorded age in 6_3a as well

******** Generating household labour variables in adult equivalent *********************
// Number of household members by gender 
bysort y2_hhid: egen male_member = count(PID) if hh_b03==1 & hh_b05a>=15
lab var male_member "male member older than 15 years"

bysort y2_hhid: egen fmale_member = count(PID) if hh_b03==2 & hh_b05a>=15
lab var fmale_member "female member older than 15 years"

bysort y2_hhid: egen cmale_member = count(PID) if hh_b03==1 & hh_b05a>5 & hh_b05a<15
lab var cmale_member "child male member less than 15 years but above 5 years"

bysort y2_hhid: egen cfmale_member = count(PID) if hh_b03==2 & hh_b05a>5 & hh_b05a<15
lab var cfmale_member "child female member less than 15 years but above 5 years"

// Labour values in adult equivalent 
****** Number of months the household member was away
rename hh_b07 month_away 
gen month_away_dummy= 1 if month_away==12
replace month_away_dummy=0 if month_away_dummy==. & month_away<12

gen adult_male_lab=1 if hh_b03==1 & hh_b05a>=15 & month_away<12
lab var adult_male_lab "adult equivalent - male labour older than 15 years"

gen adult_fmale_lab =0.8 if hh_b03==2 & hh_b05a>=15 & month_away<12
lab var adult_fmale_lab "adult equivalent - female labour older than 15 years"

gen adult_cmale_lab =0.5 if hh_b03==1 & hh_b05a>5 & hh_b05a<15 & month_away<12
lab var adult_cmale_lab "adult equivalent - male child labour less than 15 years but above 5 years"

gen adult_cfmale_lab =0.5 if hh_b03==2 & hh_b05a>5 & hh_b05a<15 & month_away<12
lab var adult_cfmale_lab "adult equivalent - female child labour less than 15 years but above 5 years"

// Total male labor. For members who were present atleast one month in the year
egen hh_male_labour  = total (adult_male_lab), by (y2_hhid)
replace hh_male_labour=0 if hh_male_labour==.
lab var hh_male_labour "Adult male labour per household"

//total female labour
egen hh_female_labour  = total (adult_fmale_lab), by (y2_hhid)
replace hh_female_labour=0 if hh_female_labour==.
lab var hh_female_labour "Adult female labour per household"

//total male child labour
egen hh_cmale_labour  = total (adult_cfmale_lab), by (y2_hhid)
replace hh_cmale_labour=0 if hh_cmale_labour==.
lab var hh_cmale_labour "Adult male child labour per household"

//total female child labour
egen hh_cfmale_labour  = total (adult_cmale_lab), by (y2_hhid)
replace hh_cfmale_labour=0 if hh_cfmale_labour==.
lab var hh_cfmale_labour "Adult female child labour per household"

// Total number of children 
egen number_children = rowtotal(cmale_member cfmale_member)
egen hh_number_children = max(number_children), by (y2_hhid)
lab var hh_number_children " Total number of children in a household under the age of 15"

// Land to adult male and female labour
egen total_male_fem_labor = rowtotal (hh_male_labour hh_female_labour)
lab var total_male_fem_labor "Total male and female labour for each household"

egen all_hh_labour = rowtotal(hh_male_labour hh_female_labour hh_cmale_labour hh_cfmale_labour)
lab var all_hh_labour " Adult equivalent labour per household"


***** Gender of household head 2013 *******
tab hh_b03 if hh_b04==1  
notes: 12 households with wife/husband as first variable while 2 with sister/bother

gen relation=1 if hh_b04==1
replace relation=1 if relation==. & hh_b04==2 & y2_hhid==1312001
replace relation=1 if relation==. & hh_b04==2 & y2_hhid==1570001
replace relation=1 if relation==. & hh_b04==2 & y2_hhid==2784001
replace relation=1 if relation==. & hh_b04==7 & y2_hhid==1622002 & hh_b05a==17
tab relation
 
gen edu_head = hh_c08
replace edu_head=0 if edu_head==. & hh_c06==2
replace edu_head=1 if edu_head==. & hh_b22_3==1
replace edu_head=8 if edu_head==. & hh_b22_3==2
replace edu_head=10 if edu_head==. & hh_b22_3==3
replace edu_head=0 if edu_head==. & hh_b22_3==. & hh_c06==.

*keep if relation==1

******Based on the entered data on 2016, the merging here is to make sure ****** 
// all yearly file have year 3 household id
merge m:1 y2_hhid using "$IHPS_analysis\2013_y3_hhid.dta", nogen force // for string variables
// 1990 household head infomation merged 

rename hh_b16 Father_info
rename hh_b22 language
rename hh_b24 Marital_status

rename hh_b26a copy_wife_hus_id
rename hh_b26b second_copy_wife_hus_id
rename hh_b26c third_copy_wife_hus_id
rename hh_c18 school_transport 

rename (hh_a10a hh_a06 hh_o00 hh_b01 panelweight) (ta_code_13 hh_a11_in13 hh_o0a_13 id_code ///
panelweight2013)

keep y3_hhid y2_hhid HHID case_id ea_id panelweight_2013 panelweight2013 hh_wgt ///
region district ta_code ta_code_13 reside dist_to_IHS3location dist_to_IHS3location hhsize ///
mover hh_a11 hh_a11_in13 hh_g09 hh_m00 hh_o0a hh_o0a_13 hh_s01 PID hhmember hh_size ///
baselinemember baselinemembercount individualmover moverbasehh ///
interview_status inter_date_v1 inter_date_v2 id_code ///
hh_x10 hh_x11 hh_x11_1 hh_x12_1 hh_x16 hh_x16_1 hh_x17 ///
hh_x18 hh_x19 hh_x20 hh_x21 hh_x22 hh_x23 ///
hh_b03 hh_b04 hh_b05a hh_b05b hh_b06_1 hh_b06_2 hh_b06_3a hh_b06_3b hh_b06a ///
hh_b06b month_away hh_b08 hh_b09 hh_b10a hh_b10b hh_b11 hh_b12 hh_b13 ///
hh_b14 hh_b15a hh_b15b Father_info hh_b19 language hh_b22_2 hh_b22_3 hh_b22_4 hh_b23 Marital_status ///
hh_b25 copy_wife_hus_id second_copy_wife_hus_id third_copy_wife_hus_id hh_b27 hh_b28 ///
year hh_c01 hh_c02 hh_c03 hh_c04 hh_c05a hh_c05b hh_c06 ///
hh_c08 hh_c09 hh_c11 hh_c12 hh_c13 ///
hh_c15 hh_c16 hh_c17 school_transport hh_c19a hh_c19b hh_c20 hh_c22a hh_c22b ///
hh_size male_member fmale_member cmale_member cfmale_member adult_male_lab ///
adult_fmale_lab adult_cmale_lab adult_cfmale_lab all_hh_labour month_away_dummy ///
hh_male_labour hh_female_labour hh_number_children total_male_fem_labor relation edu_head

// Enter rainfall data from Met department in Malawi obtained through Ministry of Agriculture
// This is annual average rainfal (mm) per district in Malawi
numlabel, add
tab district
gen rainfall_11_12=. // for 2011/12 growing season, a year before data collection in 2013
replace rainfall_11_12=1053.9 if district==101 // Chitipa
replace rainfall_11_12=1173.3 if district==102 // Karonga
replace rainfall_11_12=1447.4 if district==103 // Nkhata bay
replace rainfall_11_12=730.5 if district==104 // Rumphi
replace rainfall_11_12=722.3 if district==105 // Mzimba
replace rainfall_11_12=1000.6 if district==107 // Mzuzu city. I used Mzuzu airport 

replace rainfall_11_12=860.7 if district==201 // Kasungu
replace rainfall_11_12=1250.8 if district==202 // Nkhotakota
replace rainfall_11_12=1139.3 if district==203 // Ntchisi. Because it was missing, i used average of Nkhotakota and Dowa
replace rainfall_11_12=821.1 if district==204 // Dowa
replace rainfall_11_12=1139.2 if district==205 // Salima
replace rainfall_11_12=866.6 if district==206 // Lilongwe rural. I used Chitedze for Lilongwe rural
replace rainfall_11_12=1190.6 if district==207 // Mchinji
replace rainfall_11_12=1143.3 if district==208 // Dedza
replace rainfall_11_12=1044.1 if district==209 // Ntcheu
replace rainfall_11_12=1005.6 if district==210 // Lilongwe city. I used KIA met here 

replace rainfall_11_12=888.0 if district==301 // Mangochi
replace rainfall_11_12=920.2 if district==302 // Machinga
replace rainfall_11_12=957.0 if district==303 // Zomba
replace rainfall_11_12=888.1 if district==304 // Chiradzulu
replace rainfall_11_12=766.3 if district==305 // Blantyre rural. I used Chileka
replace rainfall_11_12=1065.2 if district==306 // Mwanza
replace rainfall_11_12=1198.5 if district==307 // Thyolo
replace rainfall_11_12=2116.6 if district==308 // Mulanje
replace rainfall_11_12=1536.8 if district==309 // Phalombe. I used average fo Zomba and Mulanje
replace rainfall_11_12=641.6 if district==310 // Chikwawa
replace rainfall_11_12=734.7 if district==311 // Nsanje
replace rainfall_11_12=334.3 if district==312 // Balaka
replace rainfall_11_12=1102.6 if district==313 // Neno
replace rainfall_11_12=887.9 if district==314 // Zomba city. I used Chancellor college
replace rainfall_11_12=1069.0 if district==315 // Blantyre city. I used Chichiri 

rename rainfall_11_12 rainfall_lag1

gen rainfall_10_11=. // for 2010/11 growing season, two years before data collection in 2013
// and 2010/11 data collection year
replace rainfall_10_11=817.8 if district==101 // Chitipa
replace rainfall_10_11=1326.2 if district==102 // Karonga
replace rainfall_10_11=1268.9 if district==103 // Nkhata bay
replace rainfall_10_11=501.3 if district==104 // Rumphi
replace rainfall_10_11=790.4 if district==105 // Mzimba
replace rainfall_10_11=986.8 if district==107 // Mzuzu city. I used Mzuzu airport 

replace rainfall_10_11=549.1 if district==201 // Kasungu
replace rainfall_10_11=1275.4 if district==202 // Nkhotakota
replace rainfall_10_11=1017.6 if district==203 // Ntchisi. Because it was missing, i used average of Nkhotakota and Dowa
replace rainfall_10_11=678.6 if district==204 // Dowa
replace rainfall_10_11=1104.8 if district==205 // Salima
replace rainfall_10_11=733.2 if district==206 // Lilongwe rural. I used Chitedze for Lilongwe rural
replace rainfall_10_11=975.5 if district==207 // Mchinji
replace rainfall_10_11=760.4 if district==208 // Dedza
replace rainfall_10_11=1099.4 if district==209 // Ntcheu
replace rainfall_10_11=723.0 if district==210 // Lilongwe city. I used KIA met here 

replace rainfall_10_11=703.5 if district==301 // Mangochi
replace rainfall_10_11=936.7 if district==302 // Machinga
replace rainfall_10_11=997.6 if district==303 // Zomba
replace rainfall_10_11=861.6 if district==304 // Chiradzulu
replace rainfall_10_11=977.2 if district==305 // Blantyre rural. I used Chileka
replace rainfall_10_11=820.6 if district==306 // Mwanza
replace rainfall_10_11=1181.5 if district==307 // Thyolo
replace rainfall_10_11=1555.3 if district==308 // Mulanje
replace rainfall_10_11=1276.4 if district==309 // Phalombe. I used average fo Zomba and Mulanje
replace rainfall_10_11=660.7 if district==310 // Chikwawa
replace rainfall_10_11=712.1 if district==311 // Nsanje
replace rainfall_10_11=376.0 if district==312 // Balaka 
replace rainfall_10_11=1048.1 if district==313 // Neno
replace rainfall_10_11=1283.8 if district==314 // Zomba city. I used Chancellor college
replace rainfall_10_11=1107.9 if district==315 // Blantyre city. I used Chichiri 

rename rainfall_10_11 rainfall_lag2

save "$temp_file_2013\hh_mod_abc_13", replace


*****************************************************

********** Working with Time use and labour ***********************
use "$IHPS_analysis\hh_mod_e_13.dta", clear
destring y2_hhid, ignore("-") replace
destring PID, replace
format %20.0g PID 
rename hh_e01 id_code
keep y2_hhid qx_type interview_status PID id_code hh_e03 ///
hh_e04 hh_e05 hh_e06 hh_e06_1 hh_e06_2 hh_e06_3 hh_e06_4 ///
hh_e06_5 hh_e06_6 hh_e06_8a hh_e06_8b hh_e07 hh_e08 hh_e09 ///
hh_e10 hh_e11 hh_e12 hh_e13_1a hh_e13_1b hh_e14 hh_e15 ///
hh_e16 hh_e17

merge 1:1 y2_hhid PID using "$temp_file_2013\hh_mod_abc_13", nogen 

********** Generating number of household members engaged in off farm activities 
count if relation==1 // Four observations had id_code starting from 2.
// These were recorded to 1
egen hh_head= min(id_code), by (y2_hhid)
replace relation=1 if relation==. & hh_head==2 & id_code==2

// agriculture farm work 
bysort y2_hhid: egen PID_crop_live_fish_work = count(PID) if hh_e06_1==1
egen hh_agrifarm_work = max(PID_crop_live_fish_work), by(y2_hhid)
replace hh_agrifarm_work=0 if hh_agrifarm_work==.
lab var hh_agrifarm_work "Number of hh members engaged in agriculture farm work by individuals"
drop PID_crop_live_fish_work

// Non farm own business by individual member 
bysort y2_hhid: egen PID_own_business = count(PID) if hh_e06_2==1
egen hh_nonfarm_own_business = max(PID_own_business), by(y2_hhid)
replace hh_nonfarm_own_business=0 if hh_nonfarm_own_business==.
lab var hh_nonfarm_own_business "Number of hh members engaged in non farm business by individuals"
drop PID_own_business

// Non farm business for the household 
bysort y2_hhid: egen PID_hh_business = count(PID) if hh_e06_3==1
egen hh_nonfarm_hh_business = max(PID_hh_business), by(y2_hhid)
replace hh_nonfarm_hh_business=0 if hh_nonfarm_hh_business==.
lab var hh_nonfarm_hh_business "Number of hh members engaged in non farm business for the household"
drop PID_hh_business

// Work for wage, salary, commission or any payment in kind excluding ganyu 
bysort y2_hhid: egen PID_longterm_employment = count(PID) if hh_e06_4==1
egen hh_longterm_employment = max(PID_longterm_employment), by(y2_hhid)
replace hh_longterm_employment=0 if hh_longterm_employment==.
lab var hh_longterm_employment "Work as employment for wage but excludidng ganyu at household level"
drop PID_longterm_employment

// Un paid apprenticeship excluding ganyu 
bysort y2_hhid: egen PID_unpaid_apprenticeship = count(PID) if hh_e06_5==1
egen hh_unpaid_apprenticeship = max(PID_unpaid_apprenticeship), by(y2_hhid)
replace hh_unpaid_apprenticeship=0 if hh_unpaid_apprenticeship==.
lab var hh_unpaid_apprenticeship "Unpaid apprenticeship but excludidng ganyu at household level"
drop PID_unpaid_apprenticeship

// Ganyu work 
bysort y2_hhid: egen PID_ganyu = count(PID) if hh_e06_6==1
egen hh_ganyu = max(PID_ganyu), by(y2_hhid)
replace hh_ganyu=0 if hh_ganyu==.
lab var hh_ganyu "Engage in casual, part time or ganyu at household level"
drop PID_ganyu

******** Keeping for household head only 
local uselabour "hh_e06_1 hh_e06_2 hh_e06_3 hh_e06_4 hh_e06_5 hh_e06_6" 
foreach var of local uselabour {
recode `var' (2=0)
label define `var' 0 "No" 1 "Yes", modify
label val `var' `var'
}
egen hh_head_offfarm=rowmax (hh_e06_2 hh_e06_3 hh_e06_4 hh_e06_5 hh_e06_6)
lab define dummy 0"No" 1"Yes"
lab values hh_head_offfarm dummy

// Generate adult equivalent labour used off their own farms

gen adultEqui_male_ganyu = adult_male_lab if hh_e06_6==1
gen adultEqui_fmale_ganyu = adult_fmale_lab if hh_e06_6==1
gen adultEqui_cmale_ganyu = adult_cmale_lab if hh_e06_6==1
gen adultEqui_cfmale_ganyu = adult_cfmale_lab if hh_e06_6==1

egen row_adulEqiva_ganyu = rowtotal (adultEqui_male_ganyu adultEqui_fmale_ganyu adultEqui_cmale_ganyu adultEqui_cfmale_ganyu)
egen adulEquiv_hh_ganyu = total (row_adulEqiva_ganyu), by(y2_hhid)

keep if relation==1


save "$temp_file_2013\labour_use_13.dta", replace

*********** Working with Shocks and Coping strategies*********
use "$IHPS_analysis\hh_mod_u_13.dta", clear
destring y2_hhid, ignore("-") replace
reshape wide occ hh_u01 hh_u0b hh_u02 hh_u03a hh_u03b hh_u03c hh_u03d hh_u03e hh_u04a hh_u04b hh_u04c, i(y2_hhid) j(hh_u0a)

********* Labeling the variables *******************************
foreach v of var hh_u0b* {
lab var `v' "Description of distress events"
}
*****
foreach v of var hh_u01* {
lab var `v' "During the last 12 months, was your HH affected negatively by any shocks"
}
*****
local count 0
foreach v of var hh_u02* {
lab var `v' "`++count' Rank the three most significant shocks you experienced"
}
*****
local count 0
foreach v of var hh_u03a* {
lab var `v' "`++count' As a result of this [SHOCK], did your income..."
}
*****
local count 0
foreach v of var hh_u03b* {
lab var `v' "`++count' As a result of this [SHOCK], did your assets..."
}
*****
local count 0
foreach v of var hh_u03c* {
lab var `v' "`++count' As a result of this [SHOCK], did your food production..."
}
*****
local count 0
foreach v of var hh_u03d* {
lab var `v' "`++count' As a result of this [SHOCK], did your food stocks..."
}
*****
local count 0
foreach v of var hh_u03e* {
lab var `v' "`++count' As a result of this [SHOCK], did your food stocks..."
}
*****
local count 0
foreach v of var hh_u04a* {
lab var `v' "`++count' Interventions to try to regain your former welfare level? (1)"
}
*****
local count 0
foreach v of var hh_u04b* {
lab var `v' "`++count' Interventions to try to regain your former welfare level? (2)"
}
*****
local count 0
foreach v of var hh_u04c* {
lab var `v' "`++count' Interventions to try to regain your former welfare level? (3)"
}
*****

rename hh_u01101 Drought
rename hh_u01102 Floods
rename hh_u01103 Earthquakes
rename hh_u01104 Unusual_crop_pest_disease
rename hh_u01105 Unusual_livestock_disease
rename hh_u01106 Unusual_low_output_prices
rename hh_u01107 Unusual_high_input_prices
rename hh_u01108 Unusual_high_food_prices
rename hh_u01109 End_regular_assistance_aid
rename hh_u01110 Lowbusinesincome_notfrom_illnes
rename hh_u01111 Businesfailure_notfrom_illnes
rename hh_u01112 Lowworkincome_notfrom_illnes
rename hh_u01113 Jobloss_notfrom_illnes 
rename hh_u01114 Serious_illness_accident
rename hh_u01115 Child_birth
rename hh_u01116 Death_income_earner
rename hh_u01117 Death_other_HHmember
rename hh_u01118 Theft
rename hh_u01119 Household_break_up
rename hh_u01120 Conflict_violence
rename hh_u01121 Others_specify
rename hh_u011101 Irregular_rains
rename hh_u04c1102 Landslides

save "$temp_file_2013\drought_13.dta", replace

****** Merging with geo-referenced data variables *******************
use "$IHPS_analysis\HouseholdGeovariables_IHPS_13.dta", clear
destring y2_hhid, ignore("-") replace
encode popdensity, gen (popu_density)
tab popu_density
recode popu_density (1=100) (2=101) (3=102) (4=103) (5=104) (6=105) ///
(7=106) (8=107) (9=108) (10=109) (11=110)
recode popu_density (100=1) (108=2) (101=3) (103=4) (105=5) (107=6) (109=7) ///
(102=8) (104=9) (106=10) (110=11)
lab define density 1"0-50" 2"50-100" 3"100-200" 4"200-300" 5"300-400" ///
6"400-500" 7"500-1000" 8"1000-2000" 9"2000-3000" 10"3000-5000" 11">5000"
lab values popu_density density 
numlabel, add
tab popu_density
save "$temp_file_2013\geo_variables_2013hh.dta", replace

****************************************************************************

********** Asset wealth for 2013 ********************************
use "$IHPS_analysis\hh_mod_l_13.dta", clear
destring y2_hhid, ignore ("-") replace
format y2_hhid %20.0g
gen total_item_cost = hh_l03* hh_l05
lab var total_item_cost "Total cost for all items"
egen total_hh_goods_wealth =total(total_item_cost), by (y2_hhid)
lab var total_hh_goods_wealth "Total cost for all durable items at household"

recode hh_l01 (2=0)
lab define dummy 0"NO" 1"YES"
lab values hh_l01 dummy

reshape wide occ hh_l01 hh_l03 hh_l04 hh_l05 total_item_cost, i(y2_hhid) j(hh_l02)

isid y2_hhid
count 
save "$temp_file_2013\hh_mod_L_13.dta", replace 

use "$IHPS_analysis\hh_mod_m_13.dta", clear
destring y2_hhid, ignore ("-") replace
format y2_hhid %20.0g
gen all_item_cost = hh_m01*hh_m06
lab var all_item_cost "Total cost for all items"
egen total_hh_farm_wealth =total(all_item_cost), by (y2_hhid)
lab var total_hh_farm_wealth "Total cost for all farm equipment at household"

replace hh_m0c=2 if hh_m00==2 & hh_m0c==.
recode hh_m0c (2=0)
lab define dummy 0"NO" 1"YES"
lab values hh_m0c dummy
reshape wide hh_m00 hh_m0b hh_m0c hh_m01 hh_m06 hh_m10 hh_m12 hh_m14 all_item_cost,i(y2_hhid) j(occ) 

recode hh_m0c* (.=0)

// Assessing the asset ownership dummy
tab hh_m0b1
tab hh_m0b2
tab hh_m0b3
tab hh_m0b4
**********************************************************
************** Merging with module L **********************
merge 1:1 y2_hhid using "$temp_file_2013\hh_mod_L_13.dta", nogen

// Factor analysis 
* variable L01 range for factor analysis: 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 5081
*variable M01 range for factor analysis: 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625
******************PCA****************************************
factor hh_l01* hh_m0c*, pcf
predict capital_asset_score

drop occ* hh_l01* hh_l03* hh_l04* hh_l05* total_item_cost* ///
hh_m00* hh_m0b* hh_m0c* hh_m01* hh_m06* hh_m10* hh_m12* hh_m14* all_item_cost*

gen total_asset_value = total_hh_farm_wealth + total_hh_goods_wealth
lab var total_asset_value "Total asset value at household level"
*sort case_id 
*quietly by case_id : gen dup = cond(_N==1,0,_n)  
*tab dup
*drop if dup>1
*drop dup
isid y2_hhid
count 
save "$temp_file_2013\hh_mod_L_M_13.dta", replace 
****************************************************************************


use "$temp_file_2013\labour_use_13.dta", clear
merge 1:1 y2_hhid using "$temp_file_2013\geo_variables_2013hh.dta", nogen
merge 1:1 y2_hhid using "$temp_file_2013\drought_13.dta", nogen
merge 1:1 y2_hhid using "$temp_file_2013\hh_mod_L_M_13.dta", nogen
isid y2_hhid
save "$temp_file_2013\hh_mod_abceulm_geo_13", replace



******** working on livestock units 2013 *******************
use "$IHPS_analysis\ag_mod_r1_13.dta", clear
destring y2_hhid,ignore("-") replace
drop if ag_r0a==.
preserve
keep y2_hhid ag_r00 ag_r0a ag_r01 ag_r01_1a ///
ag_r01_1b ag_r02 ag_r03 ag_r04 ag_r07 ag_r08
reshape wide ag_r01 ag_r01_1a ag_r01_1b ag_r02 ag_r03 ///
ag_r04 ag_r07 ag_r08, i(y2_hhid) j (ag_r0a)

rename (ag_r01301 ag_r01302 ag_r01303 ag_r01304 ag_r01307 ag_r01308 ag_r01309 ///
ag_r01311 ag_r01313 ag_r01315 ag_r01319 ag_r013304 ag_r013305 ag_r013310) ///
(cattle steer_heifer cow bull goat sheep pig local_hen local_cock duck ///
dove_pigeon ox donkey_mule_horse chicken_layer_chicken_broiler)

**** Calculating Total Livestock Units 2013 **************
gen TLU_cattle=ag_r02301*0.5 // measures for sub-saharan region
gen TLU_steer =ag_r02302*.3 // based on europe because of no figures in SSA
gen TLU_cow=ag_r02303*0.5 
gen TLU_bull=ag_r02304*0.5 
gen TLU_goat=ag_r02307*0.1
gen TLU_sheep=ag_r02308*0.1 
gen TLU_pig=ag_r02309*0.2 
gen TLU_loacl_hen=ag_r02311*0.01 
gen TLU_loacl_cock=ag_r02313*0.01 
gen TLU_duck=ag_r02315*0.03
gen TLU_dove_pigeon=ag_r02319*0.1
gen TLU_ox=ag_r023304*0.1 
gen TLU_donkey=ag_r023305*0.8  
gen TLU_chicken_broiler=ag_r023310*0.1 
 
egen total_TLU=rowtotal (TLU_donkey TLU_cattle TLU_cow TLU_bull ///
TLU_sheep TLU_goat TLU_pig TLU_loacl_hen TLU_loacl_cock ///
TLU_duck TLU_dove_pigeon TLU_chicken_broiler)

**** Gen lag TLU **************************
gen lag_TLU_donkey=ag_r073305*0.8 // measures for sub-saharan region 
gen lag_TLU_cattle=ag_r07301*0.5 
gen lag_TLU_steer =ag_r07302*.3 // based on europe because of no figures in SSA
gen lag_TLU_cow=ag_r07303*0.5 
gen lag_TLU_bull=ag_r07304*0.5 
gen lag_TLU_ox=ag_r073304*0.1 
gen lag_TLU_goat=ag_r07307*0.1
gen lag_TLU_sheep=ag_r07308*0.1 
gen lag_TLU_pig=ag_r07309*0.2 
gen lag_TLU_loacl_hen=ag_r07311*0.01 
gen lag_TLU_loacl_cock=ag_r07313*0.01 
gen lag_TLU_duck=ag_r07315*0.03
gen lag_TLU_dove_pigeon=ag_r07319*0.1
gen lag_TLU_chicken_broiler=ag_r073310*0.1 

egen lag_total_TLU=rowtotal (lag_TLU_sheep lag_TLU_pig lag_TLU_loacl_hen ///
lag_TLU_loacl_cock lag_TLU_duck lag_TLU_dove_pigeon lag_TLU_chicken_broiler )

keep y2_hhid cattle ag_r02301 ag_r07301 steer_heifer ag_r02302 ///
ag_r07302 cow ag_r02303 ag_r07303 bull ag_r02304 ag_r07304 ///
goat ag_r02307 ag_r07307 sheep ag_r02308 ag_r07308 pig ///
ag_r02309 ag_r07309 local_hen ag_r02311 ag_r07311 local_cock ///
ag_r02313 ag_r07313 duck ag_r02315 ag_r07315 ag_r01318 ///
ag_r02318 ag_r07318 dove_pigeon ag_r02319 ag_r07319 ox ///
ag_r023304 ag_r073304 donkey_mule_horse ag_r023305 ag_r073305 ///
chicken_layer_chicken_broiler ag_r023310 ag_r073310 ///
ag_r023314 ag_r073314 TLU_donkey ///
TLU_cattle TLU_steer TLU_cow TLU_bull TLU_ox TLU_goat ///
TLU_sheep TLU_pig TLU_loacl_hen TLU_loacl_cock TLU_duck ///
TLU_dove_pigeon TLU_chicken_broiler total_TLU lag_TLU_donkey ///
lag_TLU_cattle lag_TLU_steer lag_TLU_cow lag_TLU_bull ///
lag_TLU_ox lag_TLU_goat lag_TLU_sheep lag_TLU_pig ///
lag_TLU_loacl_hen lag_TLU_loacl_cock lag_TLU_duck ///
lag_TLU_dove_pigeon lag_TLU_chicken_broiler lag_total_TLU

save "$temp_file_2013\TLU_2013.dta", replace
restore 

**************** Household and livestock **********************
********* Merging household and Livestock 2013 ********
use "$temp_file_2013\hh_mod_abceulm_geo_13", clear
merge 1:1 y2_hhid using "$temp_file_2013\TLU_2013.dta", nogen
********* Because of the filter question of livestock, some households were missing
// in livestock module so i had to match a No response in question hh_s01 to be zero 
// in the total TLU variable so that i dont drop observations
replace total_TLU=0 if hh_s01==2 & total_TLU==.
replace lag_total_TLU=0 if hh_s01==2 & lag_total_TLU==.
**If a household said yes in hh_s01 but zero current or one year lag stock
// that household is considered zero for current TLU or lag TLU
replace total_TLU=0 if hh_s01==1 & total_TLU==.
replace lag_total_TLU=0 if hh_s01==1 & lag_total_TLU==.

save "$temp_file_2013\hh_mod_abceulm_geo_r_13.dta", replace 


***** Agriculture modules in 2013 ***********************
***** plot level data ************************* 
use "$IHPS_analysis\ag_mod_c_13.dta", clear
destring y2_hhid, ignore("-") replace
encode ag_c00, gen (plot_id)
encode ag_c03_2, gen (parcel_id)
numlabel, add
tab parcel_id 
tab plot_id
********* introducing y3_hhid values ************
merge m:1 y2_hhid using "$IHPS_analysis\2013_y3_hhid.dta" 
drop _merge 

// rename the codes to align to 2016 codes on these variable 
replace ag_c05e=8 if ag_c05e==2
replace ag_c05e=4 if ag_c05e==3
replace ag_c05e=3 if ag_c05e==8
label define ag_c05e0001 1 "Too far from household" 2 "Water lodged" ///
3 "Household Refused" 4 "Other (Specify)"
label values ag_c05e ag_c05e0001 
numlabel, add
tab ag_c05e
drop if plot_id==.
isid y2_hhid plot_id
save "$temp_file_2013\ag_mod_c_13.dta", replace

use "$IHPS_analysis\ag_mod_d_13.dta", clear
destring y2_hhid, ignore("-") replace
encode ag_d00, gen (plot_id)
numlabel, add
tab plot_id
drop if plot_id==.
isid y2_hhid plot_id
save "$temp_file_2013\ag_mod_d_13.dta", replace

***************************************************************
use "$temp_file_2013\ag_mod_c_13.dta", clear
merge 1:1 y2_hhid plot_id using "$temp_file_2013\ag_mod_d_13.dta", nogen
drop ag_c00 ag_c03_2 occ ag_d00
save "$temp_file_2013\ag_mod_cd_13a.dta", replace 

*** Plot geo referenced data ****************
use "$IHPS_analysis\PlotGeovariables_IHPS_13.dta", clear 
destring y2_hhid, ignore ("-") replace
format y2_hhid %12.0g
encode ag_c00, gen (plot_id)
numlabel, add
tab plot_id

recode plot_id (1=1000) (2=1010) (3=1020) (4=1030) (5=1040) (6=1050) (7=1060) (8=1070) (9=1080) ///
(10=1090) (11=1100) (12=1110) (13=1120) (14=1130) (15=1140) (16=1150) (17=1160) (18=1170) ///
(19=1180) (20=1190) (21=1200)

recode plot_id (1000=101) (1010=102) (1020=103) (1030=104) (1040=105) ///
(1050=106) (1060=107) (1070=108)(1080=1) (1090=2) (1100=3) (1110=4) (1120=5) (1130=6) ///
(1140=7) (1150=8) (1160=201) (1170=202) (1180=203) (1190=204) (1200=205) 
lab define geoplot 1"R01" 2"R02" 3"R03" 4"R04" 5"R05" 6"R06" 7"R07" 8"R08" 9"R09" ///
10"R010" 11"R011" 101"D01" 102"D02" 103"D03" 104"D04" 105"D05" 106"D06" ///
107"D07" 108"D08"201"T01" 202"T02" 203"T03" 204"T03" 205"T05" 
lab values plot_id geoplot

numlabel, add
tab plot_id
drop if plot_id==.
isid y2_hhid plot_id

***** Merging with mod c and d - plot level data
merge 1:1 y2_hhid plot_id using "$temp_file_2013\ag_mod_cd_13a.dta"
ren _merge mergegeo
save "$temp_file_2013\ag_mod_cd_plotgeo_13.dta", replace


***** creating module b2 in 2013 *****************************
// This was done by getting the variables in questionnaire used in 2016 to create module b
// and then collapse the data to available parcel information in module b1 2013
use "$temp_file_2013\ag_mod_cd_plotgeo_13.dta", clear

keep y3_hhid y2_hhid qx_type interview_status plot_id parcel_id ag_d03 ag_d03_1 ///
ag_d03_2a ag_d03_2b ag_d04a ag_d04b ag_d04_1 ag_d04_2a ag_d04_2b ag_d04_3 ///
ag_d05 ag_d06 ag_d10a ag_d10b ag_d10c ag_d10d ag_d11a ag_d11b ag_d11c ///
ag_d11d ag_d12 ag_d13a ag_d13b ag_d13_1a ag_d13_1b ag_d14 ag_d18a ag_d18b ///
ag_d18c ag_d18d ag_d19a ag_d19b ag_d19c ag_d19d dist_hh slope elevation twi ///
ag_c04a ag_c04b ag_c04c ag_c05e ag_d01 ag_d01_1 ag_d01_2a ag_d01_2b ag_d02 ag_d14 ag_d21 ///
///
ag_d47a ag_d47b ag_d47c ag_d47d ag_d47e ag_d47f ag_d47g ag_d47h ag_d47i ag_d47j ///
ag_d48a ag_d48b ag_d48c ag_d48d ag_d48e ag_d48f ag_d48g ag_d48h ag_d48i ag_d48j ///
ag_d52a ag_d52b ag_d52c ag_d53a ag_d53b ag_d53c ag_d54a ag_d54b ag_d54c ag_d55a ///
ag_d55b ag_d55c

drop if parcel_id==.

isid y2_hhid parcel_id plot_id

egen hired_farm_labour = rowmax (ag_d47a ag_d47c ag_d47e ag_d48a ag_d48c ///
ag_d48e)
gen hh_hired_farmlabour =1 if hired_farm_labour>0
replace  hh_hired_farmlabour=0 if hh_hired_farmlabour==.

egen exchange_farm_labour = rowmax (ag_d52a ag_d52b ag_d52c ag_d54a ag_d54b ag_d54c)
gen hh_exchange_in_farmlabour =1 if exchange_farm_labour>0
replace  hh_exchange_in_farmlabour=0 if hh_exchange_in_farmlabour==.

drop ag_d47a ag_d47b ag_d47c ag_d47d ag_d47e ag_d47f ag_d47g ag_d47h ag_d47i ag_d47j ///
ag_d48a ag_d48b ag_d48c ag_d48d ag_d48e ag_d48f ag_d48g ag_d48h ag_d48i ag_d48j ///
ag_d52a ag_d52b ag_d52c ag_d53a ag_d53b ag_d53c ag_d54a ag_d54b ag_d54c ag_d55a ///
ag_d55b ag_d55c

collapse (firstnm) qx_type interview_status ag_d03 ag_d03_1 ag_d03_2a ///
ag_d03_2b ag_d04a ag_d04b ag_d04_1 ag_d04_2a ag_d04_2b ag_d04_3 (sum) ag_d05 ag_d06 ///
(firstnm) ag_d10a (sum) ag_d10b ag_d10c (firstnm) ag_d10d (sum) ag_d11a ag_d11b ag_d11c ag_d11d ///
(firstnm) ag_d12 ag_d13a ag_d13b ag_d13_1a ag_d13_1b ag_d14 ag_d18a ag_d18c (sum) ag_d18b ///
(firstnm) ag_d18d ag_d19a (sum) ag_d19b (firstnm) ag_d19c ag_d19d (lastnm) plot_id ///
(max) dist_hh slope elevation twi (sum) ag_c04a (firstnm) ag_c04b ///
(sum) ag_c04c (firstnm) ag_c05e ag_d01 ag_d01_1 ag_d01_2a ag_d01_2b ag_d02 ///
ag_d21 hh_exchange_in_farmlabour hh_hired_farmlabour, by (y2_hhid parcel_id)

lab define units 1"ACRE" 2"HECTARE" 3"SQUARE METERS" 4"OTHER (SPECIFY)"
lab values ag_c04b units
lab define gps_reason 1"LONG DISTANCE WITHIN THIS DISTRICT" 2"LONG DISTANCE OUTSIDE THIS DISTRICT" ///
3"HOUSEHOLD REFUSED" 4"OTHER (SPECIFY)"
lab values ag_c05e gps_reason
lab define y_N 1"YES" 0"NO"
recode ag_d01_1 (2=0)
lab values ag_d01_1 y_N
lab values hh_hired_farmlabour y_N
lab values hh_exchange_in_farmlabour y_N
lab define usage 1"Cultivated" 2"Rented out" 3"Gave out for free" 4"Fallow" ///
5"Forest / Woodlot" 6"Pasture" 7"Other (Specify)"
lab values ag_d14 usage  
lab define soil 1"Sandy (Mchenga)" 2"Between sandy & clay(Pakati pa mchen" 3"Clay (Katondo)" ///
4" Other (Specify)"
lab values ag_d21 soil

isid y2_hhid parcel_id
recode ag_d05 ag_d06  (0=.) // The question on value was not asked on 
// rented, borrowed, leased  or moving in without permission but
// when i collpsed the data, this was turned to zero which might imply 
// zero valuation and not missing hence i changed the zero to missing 

save "$temp_file_2013\ag_mod_b2_13.dta", replace


****Combining available module b1 with created module b2 to have parcel data 2013
use "$IHPS_analysis\ag_mod_b1_13.dta", clear
destring y2_hhid, ignore("-") replace
********** introducing y3_hhid variables ************
merge m:1 y2_hhid using "$IHPS_analysis\2013_y3_hhid.dta" 
rename _merge merge9
*****************************
encode ag_b100a, gen (parcel_id)
numlabel, add
tab parcel_id
drop if parcel_id==.

isid y2_hhid parcel_id

merge 1:1 y2_hhid parcel_id using "$temp_file_2013\ag_mod_b2_13.dta"
rename _merge merge_1

label define yesno 1 "YES" 0 "NO"
recode ag_d03_1 (2=0)
label values ag_d03_1 yesno
  
recode ag_d04_3 (2=0)
label values ag_d04_3 yesno

recode ag_d04_1 (2=0)
label values ag_d04_1 yesno

rename (ag_d03 ag_d03_1 ag_d03_2a ag_d03_2b ag_d04a ag_d04b ag_d04_1 ag_d04_2a ///
ag_d04_2b ag_d04_3 ag_d05 ag_d06 ag_d10a ag_d10b ag_d10c ag_d10d ag_d11a ///
ag_d11b ag_d11c ag_d11d ag_d12 ag_d13a ag_d13b ag_d13_1a ag_d13_1b ag_d14 ///
ag_d18a ag_d18b ag_d18c ag_d18d ag_d19a ag_d19b ag_d19c ag_d19d) ///
///
(ag_b203 ag_b204_1 ag_b204_2__0 ag_b204_2__1 ag_b204_4__0 ag_b204_4__1 ag_204_5 ///
ag_b204_6__0 ag_b204_6__1 ag_b204_9 ag_b205 ag_b206 ag_b210a ag_b210b ag_b210c ///
ag_b210d ag_b211a ag_b211b ag_b211c ag_b211d ag_b212b ag_b213_1__0 ag_b213_1__1 ///
ag_b204a__0 ag_b204a__1 ag_b214 ag_b218a ag_b218b ag_b218c ag_b218d ag_b219a  ///
ag_b219b ag_b219c ag_b219d)
 
recode ag_b204_9 (2=0)
label values ag_204_5 yesno

label define d10d 1 "S:SHELLED" 2 "U:UNSHELLED" 3 "NOT APPLICABLE"
label values ag_b210d d10d
 
label define d14 1 "Cultivated" 2 "Rented out" 3 "Gave out for free" ///
4 "Fallow" 5 "Forest/woodlot" 6 "Pasture" 7 "Other (Specify)"
label values ag_b214 d14

label define d18d 1 "S:SHELLED" 2 "U:UNSHELLED" 3 "NOT APPLICABLE"
label values ag_b218d d18d
isid y2_hhid parcel_id
save "$temp_file_2013\ag_mod_b_2013.dta", replace


************ Reshaping parcel data *********************
use "$temp_file_2013\ag_mod_b_2013.dta", clear
drop merge_1 occ
rename ag_b103_1 parcel_cultivated
rename ag_b106 ag_b106a 
rename ag_b106a gps_record
rename ag_b203 land_source
rename ag_b204_1 land_title
rename ag_b205 land_sell_price
rename ag_b206 rent_land_price
rename ag_b210a crop_type
rename ag_b210c rent_price_unit
rename ag_b212b rent_payment_period
rename ag_b218a rent_recieved
rename ag_c04b land_area_unit
rename ag_c05e no_gps_reason
rename ag_d01 parcel_decision_maker
rename ag_b214 land_usage
rename twi wetness_index 

reshape wide ag_b101 ag_b100a parcel_cultivated ag_b103_2 ag_b102 ag_b104a ///
ag_b104b ag_b104c ag_b105e gps_record ag_b107 land_source land_title ag_b204_2__0 ///
ag_b204_2__1 ag_b204_4__0 ag_b204_4__1 ag_204_5 ///
ag_b204_6__0 ag_b204_6__1 ag_b204_9 land_sell_price rent_land_price crop_type ///
ag_b210b rent_price_unit ///
ag_b210d ag_b211a ag_b211b ag_b211c ag_b211d rent_payment_period ag_b213_1__0 ag_b213_1__1 ///
ag_b204a__0 ag_b204a__1 land_usage rent_recieved ag_b218b ag_b218c ag_b218d ag_b219a  ///
ag_b219b ag_b219c ag_b219d ///
dist_hh slope elevation wetness_index ag_c04a land_area_unit ag_c04c no_gps_reason ///
parcel_decision_maker ag_d01_1 ag_d01_2a ag_d01_2b ag_d02 ag_d21 plot_id ///
hh_exchange_in_farmlabour hh_hired_farmlabour, ///
i(y2_hhid) j(parcel_id)

save "$temp_file_2013\ag_mod_abcd_plotgeo_13.dta", replace 


******** Merging household and parcel agriculture data 2016*************
use "$temp_file_2013\hh_mod_abceulm_geo_r_13.dta", clear
merge 1:1 y2_hhid using "$temp_file_2013\ag_mod_abcd_plotgeo_13.dta", nogen force // for string variables 
merge m:1 district using "$rain_appended_file\rainfall data 2013.dta"
isid y2_hhid
count
save "$appended_data\hh_ag_rainy_shock_merged_13", replace
*
*
*
*
**
*
*
*
log close
translate land_labour_decisions.log land_labour_decisions.pdf , replace

